@@ -17,17 +17,16 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-	/* ------------------------------------------------------------
-	 *      add call area to list for one band
-	 *
-	 *--------------------------------------------------------------*/
+/* ------------------------------------------------------------
+ *      add call area to list for one band
+ *
+ *--------------------------------------------------------------*/
 
 
 #include <string.h>
 
 
-int add_callarea(void)
-{
+int add_callarea(void) {
     extern int callareas[];
     extern char hiscall[];
     extern int manise80;
