@@ -32,17 +32,14 @@
 #include "addmult.h"
 #include "globalvars.h"		// Includes glib.h and tlf.h
 #include "tlf_curses.h"
+#include "bands.h"
 
 #define MULTS_POSSIBLE(n) ((char *)g_ptr_array_index(mults_possible, n))
 
 enum { ALL_BAND, PER_BAND };
 
-/** Converts bandindex to bandmask */
-int inxes[NBANDS] = \
-    { BAND160, BAND80, BAND40, BAND30, BAND20, BAND17, BAND15, BAND12, BAND10 };
 
-int addmult(void)
-{
+int addmult(void) {
     int found = 0;
     int i;
     int matching_len = 0, idx = -1;
@@ -59,7 +56,7 @@ int addmult(void)
 	/* check all possible mults for match and remember the longest one */
 	for (i = 0; i < mults_possible->len; i++) {
 	    if ((strstr(ssexchange, MULTS_POSSIBLE(i)) != NULL)
-		&& (strlen(MULTS_POSSIBLE(i)) > 1)) {
+		    && (strlen(MULTS_POSSIBLE(i)) > 1)) {
 
 		if (strlen(MULTS_POSSIBLE(i)) > matching_len) {
 		    matching_len = strlen(MULTS_POSSIBLE(i));
@@ -93,7 +90,7 @@ int addmult(void)
 
     // ------------------------------- section ----------------------------
     if ((dx_arrlsections == 1) &&
-	((countrynr == w_cty) || (countrynr == ve_cty))) {
+	    ((countrynr == w_cty) || (countrynr == ve_cty))) {
 
 	/* check all possible mults for match and remember the longest one */
 	for (i = 0; i < mults_possible->len; i++) {
@@ -143,8 +140,7 @@ int addmult(void)
 
 /* -------------------------------------------------------------------*/
 
-int addmult2(void)
-{
+int addmult2(void) {
     int found = 0;
     int i;
     int matching_len = 0, idx = -1;
@@ -161,7 +157,7 @@ int addmult2(void)
 	/* check all possible mults for match and remember the longest one */
 	for (i = 0; i < mults_possible->len; i++) {
 	    if ((strstr(ssexchange, MULTS_POSSIBLE(i)) != NULL)
-		&& (strlen(MULTS_POSSIBLE(i)) > 1)) {
+		    && (strlen(MULTS_POSSIBLE(i)) > 1)) {
 
 		if (strlen(MULTS_POSSIBLE(i)) > matching_len) {
 		    matching_len = strlen(MULTS_POSSIBLE(i));
@@ -208,7 +204,7 @@ int addmult2(void)
 
 
 /* compare functions to sort multi by aphabetic order  */
-gint	cmp_size (char **a, char **b) {
+gint	cmp_size(char **a, char **b) {
 
     return g_strcmp0(*a, *b);
 }
@@ -226,8 +222,7 @@ gint	cmp_size (char **a, char **b) {
  *
  * \return number of loaded multipliers (nr of entries in mults_possible)
  * */
-int init_and_load_multipliers(void)
-{
+int init_and_load_multipliers(void) {
     extern GPtrArray *mults_possible;
     extern char multsfile[];	// Set by parse_logcfg()
 
@@ -240,7 +235,7 @@ int init_and_load_multipliers(void)
 	/* free old array if exists */
 	g_ptr_array_free(mults_possible, TRUE);
     }
-    mults_possible = g_ptr_array_new_with_free_func( g_free );
+    mults_possible = g_ptr_array_new_with_free_func(g_free);
 
 
     if (strlen(multsfile) == 0) {
@@ -250,7 +245,8 @@ int init_and_load_multipliers(void)
     // Check for mults file in working directory first
     if ((cfp = fopen(multsfile, "r")) == NULL) {
 	// Check if multsfile is in installation directory
-	if ((strlen(PACKAGE_DATA_DIR) + strlen(multsfile) + 1) <= (_POSIX_PATH_MAX * 2)) {
+	if ((strlen(PACKAGE_DATA_DIR) + strlen(multsfile) + 1) <=
+		(_POSIX_PATH_MAX * 2)) {
 	    sprintf(mults_location, "%s%s%s", PACKAGE_DATA_DIR, "/", multsfile);
 
 	    if ((cfp = fopen(mults_location, "r")) == NULL) {
@@ -259,62 +255,64 @@ int init_and_load_multipliers(void)
 		sleep(5);
 	    }
 	} else {
-	    mvprintw(9, 0, "Multiplier file path length exceeds buffer size of %d.\n", _POSIX_PATH_MAX * 2);
+	    mvprintw(9, 0, "Multiplier file path length exceeds buffer size of %d.\n",
+		     _POSIX_PATH_MAX * 2);
 	    refreshp();
 	    sleep(5);
 	}
     }
 
-    if (cfp) {
-	while (fgets(s_inputbuffer, 85, cfp) != NULL) {
-	    /* drop comments starting with '#' */
-	    if (*s_inputbuffer == '#')
-		continue;
-
-	    /* strip leading and trailing whitespace */
-	    g_strstrip(s_inputbuffer);
-	    s_inputbuffer[9] = '\0';
-
-	    /* drop empty lines */
-	    if (*s_inputbuffer == '\0')
-		continue;
-
-	    g_ptr_array_add(mults_possible, g_strdup(s_inputbuffer));
-
-	    count++;
-	}
-
-	fclose(cfp);
-
-	/* do not rely on the order in the mult file but sort it here */
-	g_ptr_array_sort(mults_possible, (GCompareFunc)cmp_size);
+    if (cfp == NULL) {
+	return 0;       // couldn't open file
     }
 
-    return (count);
+    while (fgets(s_inputbuffer, 85, cfp) != NULL) {
+	/* strip leading and trailing whitespace */
+	g_strstrip(s_inputbuffer);
+
+	/* drop comments starting with '#' and empty lines */
+	if (*s_inputbuffer == '#' || *s_inputbuffer == '\0') {
+	    continue;
+	}
+
+	s_inputbuffer[9] = '\0';
+
+	g_ptr_array_add(mults_possible, g_strdup(s_inputbuffer));
+
+	count++;
+    }
+
+    fclose(cfp);
+
+    /* do not rely on the order in the mult file but sort it here */
+    g_ptr_array_sort(mults_possible, (GCompareFunc)cmp_size);
+
+    return count;
 }
 
 
 /** initialize mults scoring
  *
- * empties mults[] and mult_bands[] arrays and set the number of
- * mults to 0.
+ * empties multis[] array, set the number of multis and multscore per band to 0.
  */
-void init_mults()
-{
+void init_mults() {
     int n;
 
     for (n = 0; n < MAX_MULTS; n++) {
-	mults[n][0] = '\0';
-	mult_bands[n] = 0;
+	multis[n].name[0] = '\0';
+	multis[n].band = 0;
     }
 
-    multarray_nr = 0;
+    nr_multis = 0;
+
+    for (n = 0; n < NBANDS; n++)
+	multscore[n] = 0;
 }
 
 /** register worked multiplier and check if its new
  *
  * Check if multiplier is already registered. If not make a new entry in
- * mults[] array and increment the total mults count 'multarray_nr'.
+ * multis[] array and increment the total mults count 'nr_multis'.
  * Mark the mult as worked on the actual band. If it is a new band
  * increase the bandspecific 'multscore[band]'.
  *
@@ -324,22 +322,21 @@ void init_mults()
  * \return	      - index in mults[] array if new mult or new on band
  *			(-1 if multiplier is an empty string or not new)
  */
-int remember_multi(char *multiplier, int band, int show_new_band)
-{
+int remember_multi(char *multiplier, int band, int show_new_band) {
     /* search multbuffer in mults arry */
     int found = 0, i, index = -1;
 
     if (*multiplier == '\0')
 	return -1;			/* ignore empty string */
 
-    for (i = 0; i < multarray_nr; i++) {
+    for (i = 0; i < nr_multis; i++) {
 	/* already in list? */
-	if (strcmp(mults[i], multiplier) == 0) {
+	if (strcmp(multis[i].name, multiplier) == 0) {
 	    found = 1;
 
 	    /* new band? */
-	    if ((mult_bands[i] & inxes[band]) == 0) {
-		mult_bands[i] |= inxes[band];
+	    if ((multis[i].band & inxes[band]) == 0) {
+		multis[i].band |= inxes[band];
 		multscore[band]++;
 
 		/* if wanted, show it as new band */
@@ -353,12 +350,12 @@ int remember_multi(char *multiplier, int band, int show_new_band)
 
     /* add new multi */
     if (found == 0) {
-	index = multarray_nr;		/* return index of new mult */
+	index = nr_multis;		/* return index of new mult */
 
-	strcpy(mults[multarray_nr], multiplier);
-	mult_bands[multarray_nr] |= inxes[band];
+	strcpy(multis[nr_multis].name, multiplier);
+	multis[nr_multis].band |= inxes[band];
 	multscore[band]++;
-	multarray_nr++;
+	nr_multis++;
     }
 
     return index;
