@@ -18,10 +18,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-	/* ------------------------------------------------------------
-	 *      audio.c   soundcard input routine
-	 *
-	 *--------------------------------------------------------------*/
+/* ------------------------------------------------------------
+ *      audio.c   soundcard input routine
+ *
+ *--------------------------------------------------------------*/
 
 
 #include <fcntl.h>
@@ -33,18 +33,12 @@
 #include <sys/ioctl.h>
 
 #include "audio.h"
+#include "gettxinfo.h"
+#include "ignore_unused.h"
 #include "tlf.h"
 #include "tlf_curses.h"
 #include "ui_utils.h"
 
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
-
-#ifdef HAVE_LIBHAMLIB
-# include <hamlib/rig.h>
-#endif
-
 #ifdef __OpenBSD__
 # include <soundcard.h>
 #else
@@ -58,8 +52,7 @@ int afd;
 
 #define ABUFSIZE          4000
 
-void init_audio()
-{
+void init_audio() {
 
     char afile[40];		/* Audio device name */
     int sndfmt;			/* Encoding of audio from */
@@ -70,7 +63,7 @@ void init_audio()
     channels = 1;
     speed = 8000;
 
-/* Audio device setup */
+    /* Audio device setup */
 
     strcpy(afile, sc_device);
 
@@ -95,8 +88,7 @@ void init_audio()
     }
 }
 
-int close_audio()
-{
+int close_audio() {
 
     close(afd);
 
@@ -105,8 +97,7 @@ int close_audio()
 
 /* ------------ rescale bar ----------*/
 
-int rescale(int testvalue)
-{
+int rescale(int testvalue) {
 
     extern int scale_values[];
 
@@ -154,8 +145,7 @@ int rescale(int testvalue)
     return (testvalue);
 }
 
-float get_audio_sample(void)
-{
+float get_audio_sample(void) {
 
     int rc = 0;			/* Return value from subs */
     static float avg = 128.0;
@@ -171,8 +161,7 @@ float get_audio_sample(void)
 	    exit(errno);
 	}
 
-	for (i = 0; i < rc; i++)	// calculate average
-	{
+	for (i = 0; i < rc; i++) {	// calculate average
 	    if ((maxval - minval) != 0.0) {
 		if (i > 2)
 		    avg =
@@ -189,8 +178,7 @@ float get_audio_sample(void)
 		avg = 128.0;
 
 	}
-	for (i = 0; i < rc; i++)	// calculate maximum avg value
-	{
+	for (i = 0; i < rc; i++) {	// calculate maximum avg value
 	    if (abuf[i] >= avg) {
 		if (i > 0)
 		    maxval =
@@ -232,8 +220,7 @@ float get_audio_sample(void)
 /* ----------make bar for s meter ------------*/
 
 int make_bar(int xpos, int ypos, int yheight, unsigned int value,
-	     int bar_type)
-{
+	     int bar_type) {
 
     int i;
 
@@ -242,7 +229,7 @@ int make_bar(int xpos, int ypos, int yheight, unsigned int value,
 	    mvprintw(ypos - i, xpos, " ");
     }
 
-/* Make the bar */
+    /* Make the bar */
 
     if (bar_type == S_BAR || bar_type == PAN_BAR) {
 	for (i = 0; i < value && i < 20; i++)
@@ -257,8 +244,7 @@ int make_bar(int xpos, int ypos, int yheight, unsigned int value,
 
 /* ------------ draw noise bridge screen ----------*/
 
-int draw_nb_screen(int xpos, int ypos, int yheight, int bar_type)
-{
+int draw_nb_screen(int xpos, int ypos, int yheight, int bar_type) {
 
     int i;
 
@@ -266,24 +252,24 @@ int draw_nb_screen(int xpos, int ypos, int yheight, int bar_type)
 
     for (i = 0; i < 21; i++) {
 	switch (i) {
-	case 0:
-	case 20:
-	    mvprintw(ypos + i, xpos,
-		     "+---------+---------+---------+---------+---------+");
-	    break;
-	case 1 ... 4:
-	case 6 ... 9:
-	case 11 ... 14:
-	case 16 ... 19:
-	    mvprintw(ypos + i, xpos,
-		     "|    |    |    |    |    |    |    |    |    |    |");
-	    break;
-	case 5:
-	case 10:
-	case 15:
+	    case 0:
+	    case 20:
+		mvprintw(ypos + i, xpos,
+			 "+---------+---------+---------+---------+---------+");
+		break;
+	    case 1 ... 4:
+	    case 6 ... 9:
+	    case 11 ... 14:
+	    case 16 ... 19:
+		mvprintw(ypos + i, xpos,
+			 "|    |    |    |    |    |    |    |    |    |    |");
+		break;
+	    case 5:
+	    case 10:
+	    case 15:
 
-	    mvprintw(ypos + i, xpos,
-		     "+----+----+----+----+----+----+----+----+----+----+");
+		mvprintw(ypos + i, xpos,
+			 "+----+----+----+----+----+----+----+----+----+----+");
 
 	}
     }
@@ -302,8 +288,7 @@ int draw_nb_screen(int xpos, int ypos, int yheight, int bar_type)
 
 /* ------------ draw scanner screen ----------*/
 
-int drawscreen(int xpos, int ypos, int yheight, int bar_type)
-{
+int drawscreen(int xpos, int ypos, int yheight, int bar_type) {
 
     int i;
 
@@ -311,24 +296,24 @@ int drawscreen(int xpos, int ypos, int yheight, int bar_type)
 
     for (i = 0; i < 21; i++) {
 	switch (i) {
-	case 0:
-	case 20:
-	    mvprintw(ypos + i, xpos,
-		     "+---------+---------+---------+---------+---------+");
-	    break;
-	case 1 ... 4:
-	case 6 ... 9:
-	case 11 ... 14:
-	case 16 ... 19:
-	    mvprintw(ypos + i, xpos,
-		     "|    |    |    |    |    |    |    |    |    |    |");
-	    break;
-	case 5:
-	case 10:
-	case 15:
+	    case 0:
+	    case 20:
+		mvprintw(ypos + i, xpos,
+			 "+---------+---------+---------+---------+---------+");
+		break;
+	    case 1 ... 4:
+	    case 6 ... 9:
+	    case 11 ... 14:
+	    case 16 ... 19:
+		mvprintw(ypos + i, xpos,
+			 "|    |    |    |    |    |    |    |    |    |    |");
+		break;
+	    case 5:
+	    case 10:
+	    case 15:
 
-	    mvprintw(ypos + i, xpos,
-		     "+----+----+----+----+----+----+----+----+----+----+");
+		mvprintw(ypos + i, xpos,
+			 "+----+----+----+----+----+----+----+----+----+----+");
 
 	}
     }
@@ -351,24 +336,24 @@ int drawscreen(int xpos, int ypos, int yheight, int bar_type)
 
 /* ------------ draw S meter screen ----------*/
 
-int drawSmeter(int xpos, int ypos, int yheight, float testvalue)
-{
+int drawSmeter(int xpos, int ypos, int yheight, float testvalue) {
+
     int i;
 
     for (i = 0; i < 21; i++) {
 	switch (i) {
-	case 0:
-	case 20:
-	    mvprintw(ypos + i, xpos, "+---+");
-	    break;
-	case 1 ... 4:
-	case 6 ... 19:
-	    mvprintw(ypos + i, xpos, "|   |");
-	    break;
-	case 5:
-	    attron(modify_attr(COLOR_PAIR(C_HEADER) | A_STANDOUT));
-	    mvprintw(ypos + i, xpos, ">   <");
-	    attron(modify_attr(COLOR_PAIR(C_WINDOW) | A_STANDOUT));
+	    case 0:
+	    case 20:
+		mvprintw(ypos + i, xpos, "+---+");
+		break;
+	    case 1 ... 4:
+	    case 6 ... 19:
+		mvprintw(ypos + i, xpos, "|   |");
+		break;
+	    case 5:
+		attron(modify_attr(COLOR_PAIR(C_HEADER) | A_STANDOUT));
+		mvprintw(ypos + i, xpos, ">   <");
+		attron(modify_attr(COLOR_PAIR(C_WINDOW) | A_STANDOUT));
 	}
     }
 
@@ -392,16 +377,9 @@ int drawSmeter(int xpos, int ypos, int yheight, float testvalue)
 
 /* ------------------ Panoramic scan -------------------- */
 
-int panscan(void)
-{
+int panscan(void) {
 
-#ifdef HAVE_LIBHAMLIB
-    extern freq_t outfreq;
-#else
-    extern int outfreq;
-#endif
-
-    int rc, j, key = 0;
+    int j, key = 0;
     float testvalue;
     float FromFrequency = 0.0;
     float FrequencyStep = 0.0;
@@ -421,29 +399,29 @@ int panscan(void)
 	mvprintw(5, 60, "Frequency: ");
 	refreshp();
 	echo();
-	rc = scanf("%f", &FromFrequency);
+	IGNORE(scanf("%f", &FromFrequency));
 	noecho();
 	mvprintw(5, 72, "%5.1f", FromFrequency);
 	mvprintw(22, 1, "%5.1f", FromFrequency);
 	refreshp();
 	mvprintw(7, 60, "Step (kHz): ");
 	refreshp();
-	rc = scanf("%f", &FrequencyStep);
+	IGNORE(scanf("%f", &FrequencyStep));
 	mvprintw(7, 72, "%5.1f", FrequencyStep);
 	refreshp();
 
 	for (j = 0; j < 51; j++) {
 	    frequencies[j] = FromFrequency + j * FrequencyStep;
 	    switch (j) {
-	    case 10:
-	    case 20:
-	    case 30:
-	    case 40:
-	    case 50:
-		mvprintw(22, j + 1, "%5.1f", frequencies[j]);
-		break;
-	    default:
-		;
+		case 10:
+		case 20:
+		case 30:
+		case 40:
+		case 50:
+		    mvprintw(22, j + 1, "%5.1f", frequencies[j]);
+		    break;
+		default:
+		    ;
 	    }
 
 	}
@@ -459,16 +437,12 @@ int panscan(void)
 	    int i;
 
 	    for (i = 0; i < 100; i++) {
-		if (outfreq == 0)
+		if (get_outfreq() == 0)
 		    break;
-		usleep(10000);
+		usleep(10 * 1000);
 	    }
 
-#ifdef HAVE_LIBHAMLIB
-	    outfreq = (freq_t) (frequencies[j] * 1000);
-#else
-	    outfreq = (int) (frequencies[j] * 1000);
-#endif
+	    set_outfreq(frequencies[j] * 1000);
 
 	    usleep(50 * 1000);
 	    testvalue = get_audio_sample();
@@ -494,15 +468,9 @@ int panscan(void)
 
 /* ------------------ Noise bridge scan -------------------- */
 
-int nbscan(void)
-{
-#ifdef HAVE_LIBHAMLIB
-    extern freq_t outfreq;
-#else
-    extern int outfreq;
-#endif
+int nbscan(void) {
 
-    int rc, j, key = 0;
+    int j, key = 0;
     float testvalue;
     float FromFrequency = 0.0;
     float FrequencyStep = 0.0;
@@ -522,28 +490,28 @@ int nbscan(void)
 	mvprintw(1, 60, "- NOISE BRIDGE -");	// get the parameters
 	mvprintw(5, 60, "Frequency: ");
 	refreshp();
-	rc = scanf("%f", &FromFrequency);
+	IGNORE(scanf("%f", &FromFrequency));
 	mvprintw(5, 72, "%5.1f", FromFrequency);
 	mvprintw(22, 1, "%5.1f", FromFrequency);
 	refreshp();
 	mvprintw(7, 60, "Step (kHz): ");
 	refreshp();
-	rc = scanf("%f", &FrequencyStep);
+	IGNORE(scanf("%f", &FrequencyStep));;
 	mvprintw(7, 72, "%5.1f", FrequencyStep);
 	refreshp();
 
 	for (j = 0; j < 51; j++) {	// draw the X scale
 	    frequencies[j] = FromFrequency + j * FrequencyStep;
 	    switch (j) {
-	    case 10:
-	    case 20:
-	    case 30:
-	    case 40:
-	    case 50:
-		mvprintw(22, j + 1, "%5.1f", frequencies[j]);
-		break;
-	    default:
-		;
+		case 10:
+		case 20:
+		case 30:
+		case 40:
+		case 50:
+		    mvprintw(22, j + 1, "%5.1f", frequencies[j]);
+		    break;
+		default:
+		    ;
 	    }
 
 	}
@@ -559,15 +527,13 @@ int nbscan(void)
 	    int i;
 
 	    for (i = 0; i < 100; i++) {
-		if (outfreq == 0)
+		if (get_outfreq() == 0)
 		    break;
-		usleep(10000);
+		usleep(10 * 1000);
 	    }
-#ifdef HAVE_LIBHAMLIB
-	    outfreq = (freq_t) (frequencies[j] * 1000);
-#else
-	    outfreq = (int) (frequencies[j] * 1000);
-#endif
+
+	    set_outfreq(frequencies[j] * 1000);
+
 	    usleep(50 * 1000);
 	    testvalue = get_audio_sample();
 	    values[j] = testvalue;
@@ -593,8 +559,7 @@ int nbscan(void)
     return (0);
 }
 
-void scanmenu(void)
-{
+void scanmenu(void) {
     int j;
 
     attron(modify_attr(COLOR_PAIR(C_WINDOW) | A_STANDOUT));
@@ -618,8 +583,7 @@ void scanmenu(void)
 
 /* -------------------main test routine ------- */
 
-int testaudio()
-{
+int testaudio() {
 
     float testvalue;
     char key = '\0';
@@ -629,7 +593,7 @@ int testaudio()
 
     scanmenu();
 
-/* ------------initialize sound card --------*/
+    /* ------------initialize sound card --------*/
     init_audio();
 
     while (runnit == 1) {
@@ -642,18 +606,18 @@ int testaudio()
 
 	switch (key) {
 
-	case '1':
-	    panscan();
-	    scanmenu();
-	    break;
-	case '2':
-	    nbscan();
-	    scanmenu();
-	    break;
+	    case '1':
+		panscan();
+		scanmenu();
+		break;
+	    case '2':
+		nbscan();
+		scanmenu();
+		break;
 
-	// <Escape>
-	case 27:
-	    runnit = 0;
+	    // <Escape>
+	    case 27:
+		runnit = 0;
 	}
     }
 
@@ -663,8 +627,7 @@ int testaudio()
     return (0);
 }
 
-void recordmenue(void)
-{
+void recordmenue(void) {
     int j;
 
     attron(modify_attr(COLOR_PAIR(C_WINDOW) | A_STANDOUT));
@@ -686,11 +649,10 @@ void recordmenue(void)
 }
 
 /*--------------------------------------------------------------------------*/
-void do_record(int message_nr)
-{
+void do_record(int message_nr) {
+
     extern char ph_message[14][80];
 
-    int rc;
     char commands[80] = "";
 
     mvprintw(15, 20, "recording %s", ph_message[message_nr]);
@@ -700,24 +662,23 @@ void do_record(int message_nr)
     strcpy(commands, "rec -r 8000 ");	//G4KNO
     strcat(commands, ph_message[message_nr]);
     strcat(commands, " -q &");	//G4KNO
-    rc = system(commands);
+    IGNORE(system(commands));;
     //G4KNO: Loop until <esc> keypress
     while (1) {
 	if (key_get() == 27) {
 	    //kill process (SIGINT=Ctrl-C).
-	    rc = system("pkill -SIGINT -n rec");
+	    IGNORE(system("pkill -SIGINT -n rec"));;
 	    break;
 	}
     }
 }
 
 /*--------------------------------------------------------------------------*/
-void record(void)
-{
+void record(void) {
 
     extern char ph_message[14][80];
 
-    int rc, runnit = 1, key, i = 0, j = 4;
+    int runnit = 1, key, i = 0, j = 4;
     char commands[80] = "";
     char playbackfile[40];
     char printname[7];
@@ -733,154 +694,154 @@ void record(void)
 	/* Look for F1-F12, s|S, c|C, 1-4 */
 	switch (key) {
 
-	/* Record voice keyer messages, F1-F12, s|S, c|C. */
-	case KEY_F(1):
-	    do_record(0);
-	    runnit = 0;
-	    break;
-	case KEY_F(2):
-	    do_record(1);
-	    runnit = 0;
-	    break;
-	case KEY_F(3):
-	    do_record(2);
-	    runnit = 0;
-	    break;
-	case KEY_F(4):
-	    do_record(3);
-	    runnit = 0;
-	    break;
-	case KEY_F(5):
-	    do_record(4);
-	    runnit = 0;
-	    break;
-	case KEY_F(6):
-	    do_record(5);
-	    runnit = 0;
-	    break;
-	case KEY_F(7):
-	    do_record(6);
-	    runnit = 0;
-	    break;
-	case KEY_F(8):
-	    do_record(7);
-	    runnit = 0;
-	    break;
-	case KEY_F(9):
-	    do_record(8);
-	    runnit = 0;
-	    break;
-	case KEY_F(10):
-	    do_record(9);
-	    runnit = 0;
-	    break;
-	case KEY_F(11):
-	    do_record(10);
-	    runnit = 0;
-	    break;
-	case KEY_F(12):
-	    do_record(11);
-	    runnit = 0;
-	    break;
-	case 's':
-	case 'S':
-	    do_record(12);
-	    runnit = 0;
-	    break;
-	case 'c':
-	case 'C':
-	    do_record(13);
-	    runnit = 0;
-	    break;
-
-	/* Contest recording and playback. */
-
-	// Start contest recording.
-	case '1':
-	    rc = system("echo " " > ~/.VRlock");
-
-	    rc = system
-		("cd ~/tlf/soundlogs; ./soundlog  > /dev/null 2> /dev/null &");
-
-	    mvprintw(15, 20, "Contest recording enabled...");
-	    refreshp();
-	    sleep(1);
-	    runnit = 0;
-	    break;
-
-	// Stop contest recording.
-	case '2':
-	    mvprintw(15, 20, "Contest recording disabled...");
-	    refreshp();
-	    sleep(1);
-	    rc = system("rm ~/.VRlock");
-	    rc = system("pkill -f soundlogs > /dev/null 2> /dev/null ");
-	    runnit = 0;
-	    break;
-
-	// List contest recordings.
-	case '3':
-	    sounddir = opendir("$HOME/tlf/soundlogs/");	// (W9WI)
-
-	    if (sounddir == NULL)
+	    /* Record voice keyer messages, F1-F12, s|S, c|C. */
+	    case KEY_F(1):
+		do_record(0);
+		runnit = 0;
+		break;
+	    case KEY_F(2):
+		do_record(1);
+		runnit = 0;
+		break;
+	    case KEY_F(3):
+		do_record(2);
+		runnit = 0;
+		break;
+	    case KEY_F(4):
+		do_record(3);
+		runnit = 0;
+		break;
+	    case KEY_F(5):
+		do_record(4);
+		runnit = 0;
+		break;
+	    case KEY_F(6):
+		do_record(5);
+		runnit = 0;
+		break;
+	    case KEY_F(7):
+		do_record(6);
+		runnit = 0;
+		break;
+	    case KEY_F(8):
+		do_record(7);
+		runnit = 0;
+		break;
+	    case KEY_F(9):
+		do_record(8);
+		runnit = 0;
+		break;
+	    case KEY_F(10):
+		do_record(9);
+		runnit = 0;
+		break;
+	    case KEY_F(11):
+		do_record(10);
+		runnit = 0;
+		break;
+	    case KEY_F(12):
+		do_record(11);
+		runnit = 0;
+		break;
+	    case 's':
+	    case 'S':
+		do_record(12);
+		runnit = 0;
+		break;
+	    case 'c':
+	    case 'C':
+		do_record(13);
+		runnit = 0;
 		break;
 
-	    for (i = 4; i < 15; i++)
-		mvprintw(i, 0,
-			 "                                                                                ");
+	    /* Contest recording and playback. */
 
-	    mvprintw(4, 10, "");
+	    // Start contest recording.
+	    case '1':
+		IGNORE(system("echo " " > ~/.VRlock"));;
 
-	    for (i = 10; i < 81; i += 10) {
-		soundfilename = readdir(sounddir);
-		if (soundfilename == NULL)
+		IGNORE(system
+		     ("cd ~/tlf/soundlogs; ./soundlog  > /dev/null 2> /dev/null &"));
+
+		mvprintw(15, 20, "Contest recording enabled...");
+		refreshp();
+		sleep(1);
+		runnit = 0;
+		break;
+
+	    // Stop contest recording.
+	    case '2':
+		mvprintw(15, 20, "Contest recording disabled...");
+		refreshp();
+		sleep(1);
+		IGNORE(system("rm ~/.VRlock"));;
+		IGNORE(system("pkill -f soundlogs > /dev/null 2> /dev/null "));;
+		runnit = 0;
+		break;
+
+	    // List contest recordings.
+	    case '3':
+		sounddir = opendir("$HOME/tlf/soundlogs/");	// (W9WI)
+
+		if (sounddir == NULL)
 		    break;
-		else {
-		    if (strstr(soundfilename->d_name, ".au") != NULL) {
-			if (i > 60) {
-			    i = 10;
-			    j++;
-			}
-			strncpy(printname, soundfilename->d_name, 6);
-			mvprintw(j, i, "%s", printname);
-			refreshp();
 
-		    } else if (i >= 10)
-			i -= 10;
+		for (i = 4; i < 15; i++)
+		    mvprintw(i, 0,
+			     "                                                                                ");
+
+		mvprintw(4, 10, "");
+
+		for (i = 10; i < 81; i += 10) {
+		    soundfilename = readdir(sounddir);
+		    if (soundfilename == NULL)
+			break;
+		    else {
+			if (strstr(soundfilename->d_name, ".au") != NULL) {
+			    if (i > 60) {
+				i = 10;
+				j++;
+			    }
+			    strncpy(printname, soundfilename->d_name, 6);
+			    mvprintw(j, i, "%s", printname);
+			    refreshp();
+
+			} else if (i >= 10)
+			    i -= 10;
+		    }
 		}
-	    }
-	    closedir(sounddir);
+		closedir(sounddir);
 
-	// Play back contest recording.
-	case '4':
-	    mvprintw(15, 20, "Play back file (ddhhmmxx): ");
-	    refreshp();
+	    // Play back contest recording.
+	    case '4':
+		mvprintw(15, 20, "Play back file (ddhhmmxx): ");
+		refreshp();
 
-	    echo();
-	    getnstr(playbackfile, 8);
-	    noecho();
-	    strcpy(commands, "play -d ");
-	    strcat(commands, sc_device);
-	    strcat(commands, " ~/tlf/soundlogs/");
-	    if (strlen(playbackfile) > 6) {
-		strncat(commands, playbackfile, 6);
-		strcat(commands, ".au trim ");
-		strcat(commands, playbackfile + 6);
-	    } else if (strlen(playbackfile) < 5) {
-		strcat(commands, playbackfile);
-		strcat(commands, "00.au");
-	    } else {
-		strcat(commands, playbackfile);
-		strcat(commands, ".au");
-	    }
-	    mvprintw(16, 20, "Use Ctrl-c to stop and return to tlf");
-	    mvprintw(18, 20, "");
-	    refreshp();
-	    rc = system(commands);
-	    runnit = 0;
-	    break;
-	case 27:
-	    runnit = 0;
+		echo();
+		getnstr(playbackfile, 8);
+		noecho();
+		strcpy(commands, "play -d ");
+		strcat(commands, sc_device);
+		strcat(commands, " ~/tlf/soundlogs/");
+		if (strlen(playbackfile) > 6) {
+		    strncat(commands, playbackfile, 6);
+		    strcat(commands, ".au trim ");
+		    strcat(commands, playbackfile + 6);
+		} else if (strlen(playbackfile) < 5) {
+		    strcat(commands, playbackfile);
+		    strcat(commands, "00.au");
+		} else {
+		    strcat(commands, playbackfile);
+		    strcat(commands, ".au");
+		}
+		mvprintw(16, 20, "Use Ctrl-c to stop and return to tlf");
+		mvprintw(18, 20, "");
+		refreshp();
+		IGNORE(system(commands));;
+		runnit = 0;
+		break;
+	    case 27:
+		runnit = 0;
 	}
     }
 
