@@ -21,6 +21,8 @@
 #ifndef _BANDMAP_H
 #define _BANDMAP_H
 
+#include "tlf.h"
+
 typedef struct {
     char 	*call;
     int 	freq;	/* freq in Hz */
@@ -29,6 +31,9 @@ typedef struct {
     char	node;
     unsigned int timeout;/* time (in seconds) left in bandmap */
     char 	dupe;	/* only used internal in bm_show() */
+    int 	cqzone;	/* CQ zone */
+    int 	ctynr;	/* Country nr */
+    char 	*pfx; /* prefix */
 } spot;
 
 #define SPOT_NEW	(bm_config.livetime)
@@ -41,6 +46,7 @@ typedef struct {
     short showdupes;
     short skipdupes;
     short livetime;
+    short onlymults;
 } bm_config_t;
 
 extern bm_config_t bm_config;
@@ -68,7 +74,7 @@ void bm_menu();
  *
  * \return true if new multi
  */
-int bm_ismulti(char *call);
+int bm_ismulti(char *call, spot *data, int band);
 
 
 /** check if call is a dupe
@@ -142,4 +148,5 @@ spot *bandmap_lookup(char *partialcall);
 spot *bandmap_next(unsigned int upwards, unsigned int freq);
 
 void get_spot_on_qrg(char *dest, float freq);
+
 #endif
