@@ -18,10 +18,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-	/* ------------------------------------------------------------
-	 *
-	 *          parameterdialog
-	 *--------------------------------------------------------------*/
+/* ------------------------------------------------------------
+ *
+ *          parameterdialog
+ *--------------------------------------------------------------*/
 
 
 #include <ctype.h>
@@ -35,7 +35,9 @@
 #include "changepars.h"
 #include "clear_display.h"
 #include "editlog.h"
+#include "fldigixmlrpc.h"
 #include "gettxinfo.h"
+#include "ignore_unused.h"
 #include "lancode.h"
 #include "listmessages.h"
 #include "logview.h"
@@ -71,8 +73,8 @@
 
 int debug_tty(void);
 
-int changepars(void)
-{
+int changepars(void) {
+
     extern int cluster;
     extern int shortqsonr;
     extern int searchflg;
@@ -93,27 +95,20 @@ int changepars(void)
     extern char *config_file;
     extern int miniterm;
     extern int total;
-
-#ifdef HAVE_LIBHAMLIB
-    extern freq_t outfreq;
-#else
-    extern int outfreq;
-#endif
-
     extern int simulator;
     extern int cwkeyer;
     extern char synclogfile[];
     extern char sc_volume[];
     extern int cwstart;
+    extern int digikeyer;
 
     char parameterstring[20];
-    char parameters[51][19];
+    char parameters[52][19];
     char cmdstring[80];
     int i, k, x, nopar = 0;
     int maxpar = 50;
     int volumebuffer;
     int currentmode = 0;
-    int rc;
 
     strcpy(parameters[0], "SPOT");
     strcpy(parameters[1], "MAP");
@@ -167,6 +162,7 @@ int changepars(void)
     strcpy(parameters[48], "SOUND");
     strcpy(parameters[49], "CWMODE");
     strcpy(parameters[50], "CHARS");
+    strcpy(parameters[51], "FLDIGI");
 
     nopar = 0;
 
@@ -193,82 +189,67 @@ int changepars(void)
     }
 
     switch (i) {
-    case 0:			/* SPOTS) */
-	{
+	case 0: {		/* SPOTS) */
 	    /* SPOTS not supported anymore
 	     * - default to MAP*/
 	    cluster = MAP;
 	    break;
 	}
-    case 1:			/* BANDMAP */
-	{
+	case 1: {		/* BANDMAP */
 	    cluster = MAP;
 	    break;
 	}
-    case 2:			/* CLOFF  */
-	{
+	case 2: {		/* CLOFF  */
 	    cluster = NOCLUSTER;
 	    break;
 	}
-    case 3:			/* CLUSTER  */
-	{
+	case 3: {		/* CLUSTER  */
 	    cluster = CLUSTER;
 	    announcefilter = FILTER_ALL;
 	    break;
 	}
-    case 4:			/* SHORTNR  */
-	{
+	case 4: {		/* SHORTNR  */
 	    shortqsonr = SHORTCW;
 	    break;
 	}
-    case 5:			/* LONGNR  */
-	{
+	case 5: {		/* LONGNR  */
 	    shortqsonr = LONGCW;
 	    break;
 	}
-    case 6:			/* MESSAGE  */
-	{
+	case 6: {		/* MESSAGE  */
 	    message_change(i);
 	    break;
 	}
 
-    case 7:			/* LIST  */
-	{
+	case 7: {		/* LIST  */
 	    listmessages();
 	    break;
 	}
-    case 8:			/* CHECK  */
-	{
+	case 8: {		/* CHECK  */
 	    searchflg = SEARCHWINDOW;
 	    break;
 	}
-    case 9:			/* NOCHECK  */
-	{
+	case 9: {		/* NOCHECK  */
 	    searchflg = 0;
 	    break;
 	}
-    case 10:			/*  TONE   */
-	{
+	case 10: {		/*  TONE   */
 	    set_tone();
 	    break;
 	}
-    case 11:			/*  EDIT   */
-	{
+	case 11: {		/*  EDIT   */
 	    logedit();
 	    break;
 	}
-    case 12:			/*  VIEW   */
-	{
+	case 12: {		/*  VIEW   */
 	    logview();
 	    break;
 	}
-    case 13:			/*  HELP   */
-	{
+	case 13: {		/*  HELP   */
 	    show_help();
 	    break;
 	}
-    case 14:			/*  DEMODE   */
-	{
+	case 14: {		/*  DEMODE   */
 	    if (demode == SEND_DE)
 		demode = 0;
 	    else
@@ -279,8 +260,7 @@ int changepars(void)
 
 	    break;
 	}
-    case 15:			/*  CONTEST   */
-	{
+	case 15: {		/*  CONTEST   */
 	    if (contest == CONTEST)
 		contest = 0;
 	    else {
@@ -293,8 +273,7 @@ int changepars(void)
 
 	    break;
 	}
-    case 16:			/*  FILTER   */
-	{
+	case 16: {		/*  FILTER   */
 	    announcefilter++;
 	    if (announcefilter > 3)
 		announcefilter = 0;
@@ -304,8 +283,7 @@ int changepars(void)
 
 	    break;
 	}
-    case 17:			/*  SCORE   */
-	{
+	case 17: {		/*  SCORE   */
 	    if (showscore_flag == 0)
 		showscore_flag = 1;
 	    else {
@@ -318,8 +296,7 @@ int changepars(void)
 
 	    break;
 	}
-    case 18:			/*  WRITE CABRILLO FILE   */
-	{
+	case 18: {		/*  WRITE CABRILLO FILE   */
 	    int old_cluster = cluster;
 	    cluster = NOCLUSTER;
 
@@ -330,9 +307,8 @@ int changepars(void)
 
 	    break;
 	}
-    case 19:			/* EXIT */
-    case 38:			/* QUIT */
-	{
+	case 19:			/* EXIT */
+	case 38: {		/* QUIT */
 	    writeparas();
 	    clear();
 	    cleanup_telnet();
@@ -341,12 +317,10 @@ int changepars(void)
 	    exit(0);
 	    break;
 	}
-    case 20:			/*  TXFILE   */
-	{
+	case 20: {		/*  TXFILE   */
 	    break;
 	}
-    case 21:			/*  ZONES   */
-	{
+	case 21: {		/*  ZONES   */
 	    if (zonedisplay == 0)
 		zonedisplay = 1;
 	    else {
@@ -356,16 +330,14 @@ int changepars(void)
 
 	    break;
 	}
-    case 22:			/* COUNTRIES */
-	{
+	case 22: {		/* COUNTRIES */
 	    show_mults();
 	    refreshp();
 	    sleep(1);
 
 	    break;
 	}
-    case 23:			/*  MODE   */
-	{
+	case 23: {		/*  MODE   */
 	    if (trxmode == CWMODE)
 		trxmode = SSBMODE;
 	    else if (trxmode == SSBMODE)
@@ -384,9 +356,8 @@ int changepars(void)
 
 	    break;
 	}
-    case 24:			/* SET PARAMETERS */
-    case 29:			/* CFG PARAMETERS */
-	{
+	case 24:			/* SET PARAMETERS */
+	case 29: {		/* CFG PARAMETERS */
 	    clear();
 	    if (editor == EDITOR_JOE) {
 		strcpy(cmdstring, "joe ");
@@ -399,7 +370,7 @@ int changepars(void)
 	    }
 
 	    strcat(cmdstring, config_file);
-	    rc = system(cmdstring);
+	    IGNORE(system(cmdstring));;
 
 	    read_logcfg();
 	    read_rules();	/* also reread rules file */
@@ -409,20 +380,17 @@ int changepars(void)
 	    clear_display();
 	    break;
 	}
-    case 25:			/*  MULTI   */
-	{
+	case 25: {		/*  MULTI   */
 	    multiplierinfo();
 
 	    break;
 	}
-    case 26:			/* PROPAGATION */
-	{
+	case 26: {		/* PROPAGATION */
 	    muf();
 	    clear_display();
 	    break;
 	}
-    case 27:			/*  RITCLEAR   */
-	{
+	case 27: {		/*  RITCLEAR   */
 	    if (rit == RITCLEAR)
 		rit = 0;
 	    else {
@@ -439,8 +407,7 @@ int changepars(void)
 
 	    break;
 	}
-    case 28:			/*  trx ctl   */
-	{
+	case 28: {		/*  trx ctl   */
 	    if (trx_control == 1)
 		trx_control = 0;
 	    else {
@@ -457,37 +424,31 @@ int changepars(void)
 
 	    break;
 	}
-    case 30:			/* CW  */
-    case 49:
-	{
+	case 30:			/* CW  */
+	case 49: {
 	    if (cwkeyer == MFJ1278_KEYER) {
 		sendmessage("MODE CW\015K\015");
 	    }
 	    trxmode = CWMODE;
-
-	    if (trx_control == 1)
-		outfreq = SETCWMODE;
+	    set_outfreq(SETCWMODE);
 	    break;
 	}
-    case 31:			/* SSBMODE  */
-	{
+	case 31: {		/* SSBMODE  */
 	    trxmode = SSBMODE;
-	    outfreq = SETSSBMODE;
+	    set_outfreq(SETSSBMODE);
 	    break;
 	}
-    case 32:			/* DIGIMODE  */
-	{
+	case 32: {		/* DIGIMODE  */
 	    trxmode = DIGIMODE;
+	    set_outfreq(SETDIGIMODE);
 	    break;
 	}
-    case 33:			/* PACKET  */
-	{
+	case 33: {		/* PACKET  */
 	    if ((nopacket == 0) && (packetinterface > 0))
 		packet();
 	    break;
 	}
-    case 34:			/* SIMULATOR  */
-	{
+	case 34: {		/* SIMULATOR  */
 	    if (simulator == 0) {
 		simulator = 1;
 		if (ctcomp == 1) {
@@ -526,8 +487,7 @@ int changepars(void)
 	    }
 	    break;
 	}
-    case 35:			/* INFO  */
-	{
+	case 35: {		/* INFO  */
 	    int currentterm = miniterm;
 	    miniterm = 0;
 	    networkinfo();
@@ -537,14 +497,12 @@ int changepars(void)
 		trxmode = DIGIMODE;
 	    break;
 	}
-    case 36:			/* CLOFF  */
-	{
+	case 36: {		/* CLOFF  */
 	    cluster = FREQWINDOW;
 	    break;
 	}
 
-    case 37:			/* RECONNECT  */
-	{
+	case 37: {		/* RECONNECT  */
 	    if ((nopacket == 0) && (packetinterface > 0)) {
 		cleanup_telnet();
 		init_packet();
@@ -553,8 +511,7 @@ int changepars(void)
 	    break;
 	}
 
-    case 39:			/* CQDELAY */
-	{
+	case 39: {		/* CQDELAY */
 	    mvprintw(12, 29, "CQD: pgup/dwn", cqdelay);
 	    refreshp();
 
@@ -564,9 +521,8 @@ int changepars(void)
 
 		switch (x) {
 
-		// <Page-Up>, increase autoCQ delay by 1/2 second.
-		case KEY_PPAGE:
-		    {
+		    // <Page-Up>, increase autoCQ delay by 1/2 second.
+		    case KEY_PPAGE: {
 			if (cqdelay <= 60) {
 			    cqdelay++;
 			    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
@@ -577,9 +533,8 @@ int changepars(void)
 			}
 		    }
 
-		// <Page-Down>, decrease autoCQ delay by 1/2 second.
-		case KEY_NPAGE:
-		    {
+		    // <Page-Down>, decrease autoCQ delay by 1/2 second.
+		    case KEY_NPAGE: {
 			if (cqdelay >= 1) {
 			    cqdelay--;
 			    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
@@ -589,9 +544,9 @@ int changepars(void)
 			    break;
 
 			}
-		default:
-			x = 0;
-		    }
+			default:
+			    x = 0;
+			}
 
 		}
 	    }
@@ -602,14 +557,12 @@ int changepars(void)
 	    break;
 
 	}
-    case 40:			/* ADIF */
-	{
+	case 40: {		/* ADIF */
 	    write_adif();
 
 	    break;
 	}
-    case 41:			/* SYNC */
-	{
+	case 41: {		/* SYNC */
 	    if (strlen(synclogfile) > 0)
 		synclog(synclogfile);
 	    scroll_log();
@@ -622,8 +575,7 @@ int changepars(void)
 	    clear_display();
 	    break;
 	}
-    case 42:			/* RESCORE */
-	{
+	case 42: {		/* RESCORE */
 	    /** \todo register return value */
 	    total = 0;
 	    readcalls();
@@ -633,8 +585,7 @@ int changepars(void)
 	    clear_display();
 	    break;
 	}
-    case 43:			/* SCVOLUME - set soundcard volume */
-	{
+	case 43: {		/* SCVOLUME - set soundcard volume */
 	    volumebuffer = atoi(sc_volume);
 	    mvprintw(12, 29, "Vol: pgup/dwn");
 	    refreshp();
@@ -648,23 +599,21 @@ int changepars(void)
 
 		switch (x) {
 
-		// <Page-Up>, increase volume by 5%.
-		case KEY_PPAGE:
-		    {
+		    // <Page-Up>, increase volume by 5%.
+		    case KEY_PPAGE: {
 			if (volumebuffer < 95)
 			    volumebuffer += 5;
 
 			break;
 		    }
-		// <Page-Down>, decrease volume by 5%.
-		case KEY_NPAGE:
-		    {
+		    // <Page-Down>, decrease volume by 5%.
+		    case KEY_NPAGE: {
 			if (volumebuffer >= 5)
 			    volumebuffer -= 5;
 
 			break;
 		    }
-		default:
+		    default:
 			x = 0;
 
 		}
@@ -682,8 +631,7 @@ int changepars(void)
 	    clear_display();
 	    break;
 	}
-    case 44:			/* SCAN */
-	{
+	case 44: {		/* SCAN */
 	    int currentterm = miniterm;
 	    miniterm = 0;
 	    testaudio();
@@ -691,42 +639,37 @@ int changepars(void)
 	    miniterm = currentterm;
 	    break;
 	}
-    case 45:			/* DEBUG */
-	{
+	case 45: {		/* DEBUG */
 	    debug_tty();
 	    clear_display();
 	    break;
 	}
-    case 46:			/* MINITERM ON/OFF */
-	{
+	case 46: {		/* MINITERM ON/OFF */
 	    if (miniterm == 1)
 		miniterm = 0;
 	    else
 		miniterm = 1;
 	    break;
 	}
-    case 47:			/* RTTY Initialize mode (MFJ1278B controller) */
-	{
+	case 47: {		/* RTTY Initialize mode (MFJ1278B controller) */
 	    sendmessage("MODE VB\015K\015");
 	    trxmode = DIGIMODE;
 
 	    break;
 	}
-    case 48:			/* SOUND */
-	{
+	case 48: {		/* SOUND */
 	    clear_display();
 	    record();
 	    clear_display();
 	    break;
 	}
-    case 50:			/* CHARS */
-	{
+	case 50: {		/* CHARS */
 	    mvprintw(13, 29, "Autosend: (0, 2..5, m)?");
 	    refreshp();
 	    x = 1;
 
 	    /* wait for correct input or ESC */
-	    while ((x != 0) && !((x >= 2) && (x <= 5)) && !(x == 'm' - '0') ) {
+	    while ((x != 0) && !((x >= 2) && (x <= 5)) && !(x == 'm' - '0')) {
 		x = key_get();
 		if (x == 27)
 		    break;
@@ -742,20 +685,32 @@ int changepars(void)
 	    }
 
 	    if (cwstart > 0)
-		mvprintw(13,29, "Autosend now: %1d        ",
-			cwstart);
+		mvprintw(13, 29, "Autosend now: %1d        ",
+			 cwstart);
 	    else {
-		if (cwstart < 0 )
-		    mvprintw(13,29, "Autosend now: Manual   ");
-	        else
-		    mvprintw(13,29, "Autosend now: OFF      ");
+		if (cwstart < 0)
+		    mvprintw(13, 29, "Autosend now: Manual   ");
+		else
+		    mvprintw(13, 29, "Autosend now: OFF      ");
 	    }
 	    refreshp();
 	    break;
 
 	}
-    default:
-	{
+        case 51: {              /* FLDIGI - turn on/off */
+	    if (digikeyer == FLDIGI) {
+		if (fldigi_toggle()) {
+		    fldigi_clear_connerr();
+		    mvprintw(13, 29, "FLDIGI ON");
+	        }
+	        else {
+		    mvprintw(13, 29, "FLDIGI OFF");
+		}
+		refreshp();
+	    }
+	    break;
+	}
+	default: {
 	    nopar = 1;
 	}
     }
@@ -782,8 +737,8 @@ int changepars(void)
 
 /* -------------------------------------------------------------- */
 
-int networkinfo(void)
-{
+int networkinfo(void) {
+
     extern int use_bandoutput;
     extern int recv_packets;
     extern int recv_error;
@@ -796,7 +751,7 @@ int networkinfo(void)
     extern char whichcontest[];
     extern char pr_hostaddress[];
     extern char tncportname[];
-    extern char rigportname[];
+    extern char *rigportname;
     extern char logfile[];
 
     int i, j, inode;
@@ -858,14 +813,13 @@ int networkinfo(void)
 
 /* -------------------------------------------------------------- */
 
-int multiplierinfo(void)
-{
+int multiplierinfo(void) {
+
     extern int arrlss;
     extern int serial_section_mult;
     extern int sectn_mult;
-    extern char mults[MAX_MULTS][12];
-    extern int mult_bands[MAX_MULTS];
-    extern int multarray_nr;
+    extern struct mults_t multis[MAX_MULTS];
+    extern int nr_multis;
     extern GPtrArray *mults_possible;
 
     int j, k, vert, hor, cnt, found;
@@ -899,8 +853,8 @@ int multiplierinfo(void)
 
 		/* check if in worked multis */
 		found = 0;
-		for (j = 0; j < multarray_nr; j++) {
-		    g_strlcpy(ch2mult, mults[j], sizeof(ch2mult));
+		for (j = 0; j < nr_multis; j++) {
+		    g_strlcpy(ch2mult, multis[j].name, sizeof(ch2mult));
 
 		    if (strcmp(g_strchomp(ch2mult), chmult) == 0)
 			found = 1;
@@ -922,7 +876,7 @@ int multiplierinfo(void)
     }
 
     if (serial_section_mult == 1 || (sectn_mult == 1 && arrlss != 1)) {
-	char * tmp;
+	char *tmp;
 	int worked_at;
 
 	mvprintw(0, 30, "REMAINING SECTIONS");
@@ -938,9 +892,9 @@ int multiplierinfo(void)
 		worked_at = 0;
 
 		/* lookup if already worked */
-		for (k = 0; k < multarray_nr; k++) {
-		    if (strstr(mults[k], MULTS_POSSIBLE(cnt)) != NULL) {
-			worked_at = mult_bands[k];
+		for (k = 0; k < nr_multis; k++) {
+		    if (strstr(multis[k].name, MULTS_POSSIBLE(cnt)) != NULL) {
+			worked_at = multis[k].band;
 			break;
 		    }
 		}
@@ -949,12 +903,12 @@ int multiplierinfo(void)
 		sprintf(mprint, "%-4s", tmp);
 		g_free(tmp);
 
-		strcat(mprint, (worked_at & BAND160)?"*":"-");
-		strcat(mprint, (worked_at & BAND80)?"*":"-");
-		strcat(mprint, (worked_at & BAND40)?"*":"-");
-		strcat(mprint, (worked_at & BAND20)?"*":"-");
-		strcat(mprint, (worked_at & BAND15)?"*":"-");
-		strcat(mprint, (worked_at & BAND10)?"*":"-");
+		strcat(mprint, (worked_at & BAND160) ? "*" : "-");
+		strcat(mprint, (worked_at & BAND80) ? "*" : "-");
+		strcat(mprint, (worked_at & BAND40) ? "*" : "-");
+		strcat(mprint, (worked_at & BAND20) ? "*" : "-");
+		strcat(mprint, (worked_at & BAND15) ? "*" : "-");
+		strcat(mprint, (worked_at & BAND10) ? "*" : "-");
 
 		mprint[11] = '\0';
 		mvprintw(vert, 2 + hor * 11, "%s", mprint);
@@ -986,21 +940,20 @@ int multiplierinfo(void)
 
 /* ------------------------- radio link debug ------------------------------ */
 
-int debug_tty(void)
-{
+int debug_tty(void) {
 
-    extern char rigportname[];
+    extern char *rigportname;
     extern int serial_rate;
 
     int fdSertnc;
     int tncport = 0;
-    int i, rc;
+    int i;
     struct termios termattribs;
     char line[20] = "?AF\015";
     char inputline[80] = "";
     const char eom[2] = { '\015', '\0' };
 
-/* initialize ttyS0*/
+    /* initialize ttyS0*/
 
     for (i = 0; i < 24; i++)
 	mvprintw(i, 0,
@@ -1050,36 +1003,36 @@ int debug_tty(void)
 
     switch (serial_rate) {
 
-    case 1200:{
+	case 1200: {
 	    cfsetispeed(&termattribs, B1200);	/* Set input speed */
 	    cfsetospeed(&termattribs, B1200);	/* Set output speed */
 	    break;
 	}
 
-    case 2400:{
+	case 2400: {
 	    cfsetispeed(&termattribs, B2400);	/* Set input speed */
 	    cfsetospeed(&termattribs, B2400);	/* Set output speed */
 	    break;
 	}
 
-    case 4800:{
+	case 4800: {
 	    cfsetispeed(&termattribs, B4800);	/* Set input speed */
 	    cfsetospeed(&termattribs, B4800);	/* Set output speed */
 	    break;
 	}
 
-    case 9600:{
+	case 9600: {
 	    cfsetispeed(&termattribs, B9600);	/* Set input speed */
 	    cfsetospeed(&termattribs, B9600);	/* Set output speed */
 	    break;
 	}
-    case 57600:{
+	case 57600: {
 	    cfsetispeed(&termattribs, B57600);	/* Set input speed */
 	    cfsetospeed(&termattribs, B57600);	/* Set output speed */
 	    break;
 	}
 
-    default:{
+	default: {
 
 	    cfsetispeed(&termattribs, B9600);	/* Set input speed */
 	    cfsetospeed(&termattribs, B9600);	/* Set output speed */
@@ -1098,12 +1051,12 @@ int debug_tty(void)
     noecho();
     strcat(line, eom);
 
-/* send message */
+    /* send message */
     mvprintw(7, 0, "sending message to trx: %s", line);
     mvprintw(7, 40, "Length = %d characters", strlen(line));
     refreshp();
 
-    rc = write(fdSertnc, line, strlen(line));
+    IGNORE(write(fdSertnc, line, strlen(line)));;
 
     mvprintw(8, 0, "receiving message from trx");
     refreshp();
@@ -1126,7 +1079,7 @@ int debug_tty(void)
 	}
 	mvprintw(8, 40, "Length = %d characters", i);
 	if (inputline[0] == '@' && inputline[1] == 'A'
-	    && inputline[2] != 'F') {
+		&& inputline[2] != 'F') {
 	    mvprintw(20, 0, "Frequency = %d Hz",
 		     ((inputline[3] & 0xff) * 65536) +
 		     ((inputline[4] & 0xff) * 256) +
@@ -1141,7 +1094,7 @@ int debug_tty(void)
     refreshp();
     (void)key_get();
 
-/* close the tty */
+    /* close the tty */
 
     if (fdSertnc > 0)
 	close(fdSertnc);
