@@ -17,13 +17,13 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-	/* ------------------------------------------------------------
-	 *    make sure logfile is present and can be opened for append
-	 *    - create one if it does not exist
-	 *    - check that length of logfile is a integer m^ultiple of
-	 *      the loglinelen
-	 *
-	 *--------------------------------------------------------------*/
+/* ------------------------------------------------------------
+ *    make sure logfile is present and can be opened for append
+ *    - create one if it does not exist
+ *    - check that length of logfile is a integer m^ultiple of
+ *      the loglinelen
+ *
+ *--------------------------------------------------------------*/
 
 
 #include <errno.h>
@@ -36,6 +36,7 @@
 
 #include <glib.h>
 
+#include "ignore_unused.h"
 #include "startmsg.h"
 #include "tlf.h"
 #include "tlf_curses.h"
@@ -61,27 +62,27 @@ int repair_log(char *filename) {
 
     /* make a backup of the original file */
     backupfile = g_strconcat(filename, ".bak", NULL);
-    showstring ( "Backing up original file as: ", backupfile);
+    showstring("Backing up original file as: ", backupfile);
 
     cmd = g_strconcat("cp ", filename, " ", backupfile, NULL);
     rc = system(cmd);
     g_free(cmd);
 
     if (rc != 0) {
-	showmsg( "Could not backup logfile. Giving up!" );
+	showmsg("Could not backup logfile. Giving up!");
 	return 1;
     }
 
 
-    showmsg( "Converting file to new format");
+    showmsg("Converting file to new format");
     if ((infp = fopen(backupfile, "r")) == NULL) {
-	showmsg( "Could not convert logfile. Sorry!" );
+	showmsg("Could not convert logfile. Sorry!");
 	return 1;
     }
 
     if ((outfp = fopen(filename, "w")) == NULL) {
 	fclose(infp);
-	showmsg( "Could not convert logfile. Sorry!" );
+	showmsg("Could not convert logfile. Sorry!");
 	return 1;
     }
 
@@ -91,7 +92,7 @@ int repair_log(char *filename) {
 	g_strchomp(buffer);
 
 	/* append spaces */
-	fill = g_strnfill( (LOGLINELEN-1) - strlen(buffer), ' ' );
+	fill = g_strnfill((LOGLINELEN - 1) - strlen(buffer), ' ');
 	strcat(buffer, fill);
 	g_free(fill);
 
@@ -104,7 +105,7 @@ int repair_log(char *filename) {
 
     g_free(backupfile);
 
-    showmsg( "Done" );
+    showmsg("Done");
     sleep(2);
 
     return 0;
@@ -112,8 +113,8 @@ int repair_log(char *filename) {
 
 
 
-int checklogfile_new(char *filename)
-{
+int checklogfile_new(char *filename) {
+
     int lineno;
     int tooshort;
     char buffer[160];
@@ -123,25 +124,25 @@ int checklogfile_new(char *filename)
     if ((fp = fopen(filename, "r")) == NULL) {
 
 	if (errno == EACCES) {
-	    showstring( "Can not access log file: ", filename);
+	    showstring("Can not access log file: ", filename);
 	    return 1;
 	}
 
 	if (errno == ENOENT) {
 	    /* File not found, create new one */
-	    showmsg( "Log file not found, creating new one");
+	    showmsg("Log file not found, creating new one");
 	    sleep(2);
 	    if ((fp = fopen(filename, "w")) == NULL) {
 		/* cannot create logfile */
-		showmsg( "Creating logfile not possible");
-	        return 1;
+		showmsg("Creating logfile not possible");
+		return 1;
 	    }
 	    /* New logfile created */
 	    fclose(fp);
 	    return 0;
 	}
 
-	showstring( "Can not check log file: ", filename);
+	showstring("Can not check log file: ", filename);
 	return 1;
     }
 
@@ -160,19 +161,19 @@ int checklogfile_new(char *filename)
 	band = atoi(buffer);
 
 	if ((band == 160) ||
-	    (band == 80) ||
-	    (band == 40) ||
-	    (band == 30) ||
-	    (band == 20) ||
-	    (band == 17) ||
-	    (band == 15) ||
-	    (band == 12) ||
-	    (band == 10))
-		bandok = 1;
+		(band == 80) ||
+		(band == 40) ||
+		(band == 30) ||
+		(band == 20) ||
+		(band == 17) ||
+		(band == 15) ||
+		(band == 12) ||
+		(band == 10))
+	    bandok = 1;
 
 	if (!((buffer[0] == ';') || bandok)) {
 	    /* msg no valid logline in line #, cannot handle it */
-	    shownr( "No valid log line in line ", lineno);
+	    shownr("No valid log line in line ", lineno);
 	    return 1;
 	}
 
@@ -182,8 +183,8 @@ int checklogfile_new(char *filename)
 	if (linelen > LOGLINELEN) {
 	    /* msg length of line # to long,
 	     * cannot handle that log file format */
-	    shownr( "Log line to long in line ", lineno);
-	    showmsg( "Can not handle that log format");
+	    shownr("Log line to long in line ", lineno);
+	    showmsg("Can not handle that log format");
 	    return 1;
 	}
 
@@ -199,10 +200,10 @@ int checklogfile_new(char *filename)
 	char c;
 
 	/* some lines in logfile are too short, maybe old logfile format */
-	showmsg( "Some log lines are too short (maybe an old log format)!" );
-	showmsg( "Shall I try to repair? Y/(N) " );
+	showmsg("Some log lines are too short (maybe an old log format)!");
+	showmsg("Shall I try to repair? Y/(N) ");
 	echo();
-	c = toupper( key_get() );
+	c = toupper(key_get());
 	noecho();
 
 	if (c != 'Y') {
@@ -217,20 +218,16 @@ int checklogfile_new(char *filename)
 }
 
 
-void checklogfile(void)
-{
+void checklogfile(void) {
 
     extern char logfile[];
     extern char backgrnd_str[];
 
     int lfile;
     int qsobytes;
-    int qsolines;
     int errbytes;
-    int rc;
     struct stat statbuf;
     char inputbuffer[800];
-    char *rp;
 
     FILE *infile;
     FILE *outfile;
@@ -244,7 +241,6 @@ void checklogfile(void)
 
 	fstat(fileno(fp), &statbuf);
 	qsobytes = statbuf.st_size;
-	qsolines = qsobytes / LOGLINELEN;
 	errbytes = qsobytes % LOGLINELEN;
 
 	if (errbytes != 0) {
@@ -266,7 +262,7 @@ void checklogfile(void)
 
 		    while (!(feof(infile))) {
 
-			rp = fgets(inputbuffer, 160, infile);
+			IGNORE(fgets(inputbuffer, 160, infile));;
 
 			if (strlen(inputbuffer) != LOGLINELEN) {
 			    strcat(inputbuffer, backgrnd_str);
@@ -291,7 +287,7 @@ void checklogfile(void)
 		    fstat(lfile, &statbuf);
 
 		    if (statbuf.st_size > 80) {
-			rc = ftruncate(lfile, statbuf.st_size - LOGLINELEN);
+			IGNORE(ftruncate(lfile, statbuf.st_size - LOGLINELEN));;
 			fsync(lfile);
 
 		    }
