@@ -17,18 +17,23 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-	/* ------------------------------------------------------------
-	 *      get trx info
-	 *
-	 *--------------------------------------------------------------*/
+/* ------------------------------------------------------------
+ *      get trx info
+ *
+ *--------------------------------------------------------------*/
 
 
 #include <unistd.h>
+#include <sys/time.h>
+#include <pthread.h>
 
+#include "bands.h"
 #include "fldigixmlrpc.h"
 #include "gettxinfo.h"
 #include "tlf.h"
 #include "tlf_curses.h"
+#include "callinput.h"
+#include "bands.h"
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -43,25 +48,70 @@
 #endif
 #endif
 
-int gettxinfo(void)
-{
+#ifdef HAVE_LIBHAMLIB
+extern RIG *my_rig;
+extern int cw_bandwidth;
+extern int trxmode;
+extern int rigmode;
+extern int digikeyer;
+extern rmode_t digi_mode;
+#endif
+
+extern float freq;
+extern int bandinx;
+extern float bandfrequency[];
+
+extern int trx_control;
+extern unsigned char rigptt;
+
+/* output frequency to rig or other rig-related request
+ *
+ * possible values:
+ *  0 - poll rig
+ *  SETCWMODE
+ *  SETSSBMODE
+ *  RESETRIT
+ *  SETDIGIMODE
+ *  else - set rig frequency
+ *
+ */
+#ifdef HAVE_LIBHAMLIB
+static freq_t outfreq = 0;
+#else
+static int outfreq = 0;
+#endif
+
+static pthread_mutex_t outfreq_mutex = PTHREAD_MUTEX_INITIALIZER;
+
 
 #ifdef HAVE_LIBHAMLIB
-    extern RIG *my_rig;
-    extern freq_t outfreq;
-    extern int cw_bandwidth;
-    extern int trxmode;
-    extern int rigmode;
-    extern int digikeyer;
-#else
-    extern int outfreq;
+static double get_current_seconds();
 #endif
-    extern float freq;
-    extern int bandinx;
-    extern float bandfrequency[];
+static void handle_trx_bandswitch(int freq);
 
-    extern int trx_control;
-    extern unsigned char rigptt;
+void set_outfreq(double hertz) {
+    if (!trx_control) {
+	hertz = 0;      // no rig control, ignore request
+    }
+    pthread_mutex_lock(&outfreq_mutex);
+    outfreq = hertz;
+    pthread_mutex_unlock(&outfreq_mutex);
+}
+
+double get_outfreq() {
+    return outfreq;
+}
+
+static double get_and_reset_outfreq() {
+    pthread_mutex_lock(&outfreq_mutex);
+    double f = outfreq;
+    outfreq = 0.0;
+    pthread_mutex_unlock(&outfreq_mutex);
+    return f;
+}
+
+
+void gettxinfo(void) {
 
 #ifdef HAVE_LIBHAMLIB
     freq_t rigfreq;
@@ -69,18 +119,20 @@ int gettxinfo(void)
     pbwidth_t bwidth;
     int retval;
     int retvalmode;
+    static double last_freq_time = 0.0;
 #else
     float rigfreq;
 #endif
 
     static int oldbandinx;
+#ifdef HAVE_LIBHAMLIB		// Code for Hamlib interface
     static int fldigi_carrier;
     static int fldigi_shift_freq;
+#endif
 
-    void send_bandswitch(int freq);
 
-    if (trx_control != 1)
-	return (0);
+    if (!trx_control)
+	return;
 
 #ifdef HAVE_LIBHAMLIB
     /* CAT PTT wanted, available, inactive, and PTT On requested
@@ -110,16 +162,24 @@ int gettxinfo(void)
     }
 #endif
 
-    if (outfreq == 0) {
+    double reqf = get_and_reset_outfreq();  // get actual request
+
+    if (reqf == 0) {
 
 	rigfreq = 0.0;
 
 #ifdef HAVE_LIBHAMLIB		// Code for Hamlib interface
+	double now = get_current_seconds();
+	if (now < last_freq_time + 0.2) {
+	    return;   // last read-out was within 200 ms, skip this query
+	}
+	last_freq_time = now;
+
 	retval = rig_get_vfo(my_rig, &vfo); /* initialize RIG_VFO_CURR */
 	if (retval == RIG_OK || retval == -RIG_ENIMPL || retval == -RIG_ENAVAIL) {
 	    retval = rig_get_freq(my_rig, RIG_VFO_CURR, &rigfreq);
 	    if (trxmode == DIGIMODE && (digikeyer == GMFSK || digikeyer == FLDIGI)
-			&& retval == RIG_OK) {
+		    && retval == RIG_OK) {
 		retvalmode = rig_get_mode(my_rig, RIG_VFO_CURR, (rmode_t *)&rigmode, &bwidth);
 		if (retvalmode != RIG_OK) {
 		    rigmode = RIG_MODE_NONE;
@@ -133,14 +193,15 @@ int gettxinfo(void)
 	    if (rigmode == RIG_MODE_RTTY || rigmode == RIG_MODE_RTTYR) {
 		fldigi_shift_freq = fldigi_get_shift_freq();
 		if (fldigi_shift_freq != 0) {
-		    retval = rig_set_freq(my_rig, RIG_VFO_CURR, ((freq_t)rigfreq + (freq_t)fldigi_shift_freq));
+		    retval = rig_set_freq(my_rig, RIG_VFO_CURR,
+					  ((freq_t)rigfreq + (freq_t)fldigi_shift_freq));
 		}
 	    }
 	}
 
 	if (retval != RIG_OK || rigfreq < 0.1) {
 	    freq = 0.0;
-	    return (0);
+	    return;
 	}
 #endif
 
@@ -149,127 +210,26 @@ int gettxinfo(void)
 	    freq = rigfreq / 1000.0;		/* kHz */
 	}
 
+	bandinx = freq2band((unsigned int)(freq * 1000.0));
 
-	switch ((int)freq) {
-	case 1800 ... 2000:{
-		bandinx = 0;
-		break;
-	    }
-	case 3500 ... 4000:{
-		bandinx = 1;
-		break;
-	    }
-	case 7000 ... 7300:{
-		bandinx = 2;
-		break;
-	    }
-	case 10100 ... 10150:{
-		bandinx = 3;
-		break;
-	    }
-	case 14000 ... 14350:{
-		bandinx = 4;
-		break;
-	    }
-	case 18068 ... 18168:{
-		bandinx = 5;
-		break;
-	    }
-	case 21000 ... 21450:{
-		bandinx = 6;
-		break;
-	    }
-	case 24890 ... 24990:{
-		bandinx = 7;
-		break;
-	    }
-	case 28000 ... 29700:{
-		bandinx = 8;
-		break;
-	    }
-	default:
-		bandinx = NBANDS;	/* out of band */
-	}
+	bandfrequency[bandinx] = freq;
 
-	if (bandinx != NBANDS)
-	    bandfrequency[bandinx] = freq;
-
-	if (bandinx != oldbandinx)	// band change on trx
-	{
+	if (bandinx != oldbandinx) {	// band change on trx
 	    oldbandinx = bandinx;
-	    send_bandswitch((int) freq);
-
-
-#ifdef HAVE_LIBHAMLIB		// Code for Hamlib interface
-
-	    if (trxmode == SSBMODE) {
-		if (freq < 14000.0)
-		    retval =
-			rig_set_mode(my_rig, RIG_VFO_CURR,
-				     RIG_MODE_LSB,
-				     TLF_DEFAULT_PASSBAND);
-		else
-		    retval =
-			rig_set_mode(my_rig, RIG_VFO_CURR,
-				     RIG_MODE_USB,
-				     TLF_DEFAULT_PASSBAND);
-
-		if (retval != RIG_OK) {
-		    mvprintw(24, 0,
-			     "Problem with rig link: set mode!\n");
-		    refreshp();
-		    sleep(1);
-		}
-	    } else if (trxmode == DIGIMODE) {
-                if ((rigmode & (RIG_MODE_LSB | RIG_MODE_USB | RIG_MODE_RTTY | RIG_MODE_RTTYR)) != rigmode) {
-		    retval =
-		    	rig_set_mode(my_rig, RIG_VFO_CURR, RIG_MODE_LSB,
-				 TLF_DEFAULT_PASSBAND);
-
-		    if (retval != RIG_OK) {
-			mvprintw(24, 0,
-			     "Problem with rig link: set mode!\n");
-			refreshp();
-		    	sleep(1);
-                    }
-		}
-
-	    } else {
-//                                      retval =  rig_set_mode(my_rig, RIG_VFO_CURR, RIG_MODE_CW,  TLF_DEFAULT_PASSBAND);
-		if (cw_bandwidth == 0) {
-			retval =
-			    rig_set_mode(my_rig, RIG_VFO_CURR,
-					 RIG_MODE_CW,
-					 TLF_DEFAULT_PASSBAND);
-		} else {
-			retval =
-			    rig_set_mode(my_rig, RIG_VFO_CURR,
-					 RIG_MODE_CW, cw_bandwidth);
-		}
-
-		if (retval != RIG_OK) {
-		    mvprintw(24, 0,
-			     "Problem with rig link: set mode!\n");
-		    refreshp();
-		    sleep(1);
-		}
-
-	    }
-#endif
-
+	    handle_trx_bandswitch((int) freq);
 	}
 
-    } else if (outfreq == SETCWMODE) {
+    } else if (reqf == SETCWMODE) {
 
 #ifdef HAVE_LIBHAMLIB		// Code for Hamlib interface
 	if (cw_bandwidth == 0) {
 	    retval =
 		rig_set_mode(my_rig, RIG_VFO_CURR, RIG_MODE_CW,
-				 TLF_DEFAULT_PASSBAND);
+			     TLF_DEFAULT_PASSBAND);
 	} else {
 	    retval =
 		rig_set_mode(my_rig, RIG_VFO_CURR, RIG_MODE_CW,
-				 cw_bandwidth);
+			     cw_bandwidth);
 	}
 
 	if (retval != 0) {
@@ -279,9 +239,7 @@ int gettxinfo(void)
 	}
 #endif
 
-	outfreq = 0;
-
-    } else if (outfreq == SETSSBMODE) {
+    } else if (reqf == SETSSBMODE) {
 #ifdef HAVE_LIBHAMLIB		// Code for Hamlib interface
 	if (freq > 13999.9)
 	    retval =
@@ -299,42 +257,99 @@ int gettxinfo(void)
 	}
 #endif
 
-	outfreq = 0;
-
-    } else if (outfreq == RESETRIT) {
+    } else if (reqf == SETDIGIMODE) {
 #ifdef HAVE_LIBHAMLIB		// Code for Hamlib interface
-	    retval = rig_set_rit(my_rig, RIG_VFO_CURR, 0);
+	rmode_t new_mode = digi_mode;
+	if (new_mode == RIG_MODE_NONE) {
+	    if (digikeyer == FLDIGI)
+		new_mode = RIG_MODE_USB;
+	    else
+		new_mode = RIG_MODE_LSB;
+	}
+	retval =
+	    rig_set_mode(my_rig, RIG_VFO_CURR, new_mode,
+		TLF_DEFAULT_PASSBAND);
 
-	    if (retval != RIG_OK) {
-		mvprintw(24, 0, "Problem with rig link!\n");
-		refreshp();
-		sleep(1);
-	    }
+	if (retval != RIG_OK) {
+	    mvprintw(24, 0, "Problem with rig link!\n");
+	    refreshp();
+	    sleep(1);
+	}
 #endif
 
-	outfreq = 0;
+    } else if (reqf == RESETRIT) {
+#ifdef HAVE_LIBHAMLIB		// Code for Hamlib interface
+	retval = rig_set_rit(my_rig, RIG_VFO_CURR, 0);
+
+	if (retval != RIG_OK) {
+	    mvprintw(24, 0, "Problem with rig link!\n");
+	    refreshp();
+	    sleep(1);
+	}
+#endif
 
     } else {
-
+	// set rig frequency to `reqf'
 #ifdef HAVE_LIBHAMLIB		// Code for Hamlib interface
-	retval = rig_set_freq(my_rig, RIG_VFO_CURR, outfreq);
+	retval = rig_set_freq(my_rig, RIG_VFO_CURR, (freq_t) reqf);
 
 	if (retval != RIG_OK) {
 	    mvprintw(24, 0, "Problem with rig link: set frequency!\n");
 	    refreshp();
 	    sleep(1);
 	}
-
-	if (retval != 0) {
-	    mvprintw(24, 0, "Problem with rig link: set frequency!\n");
-	    refreshp();
-	    sleep(1);
-	}
 #endif
 
-	outfreq = 0;
-
     }
 
-    return (0);
 }
+
+
+#ifdef HAVE_LIBHAMLIB
+static double get_current_seconds() {
+    struct timeval tv;
+    gettimeofday(&tv, NULL);
+    return tv.tv_sec + tv.tv_usec / 1e6;
+}
+#endif
+
+
+static void handle_trx_bandswitch(int freq) {
+
+    send_bandswitch(freq);
+
+#ifdef HAVE_LIBHAMLIB		// Code for Hamlib interface
+
+    rmode_t mode = RIG_MODE_NONE;           // default: no change
+    pbwidth_t width = TLF_DEFAULT_PASSBAND; // passband width, in Hz
+
+    if (trxmode == SSBMODE) {
+	mode = (freq < 14000 ? RIG_MODE_LSB : RIG_MODE_USB);
+    } else if (trxmode == DIGIMODE) {
+	if ((rigmode & (RIG_MODE_LSB | RIG_MODE_USB | RIG_MODE_RTTY | RIG_MODE_RTTYR))
+		!= rigmode) {
+	    mode = RIG_MODE_LSB;
+	}
+    } else {
+	mode = RIG_MODE_CW;
+	if (cw_bandwidth != 0) {
+	    width = cw_bandwidth;
+	}
+    }
+
+    if (mode == RIG_MODE_NONE) {
+	return;     // no change was requested
+    }
+
+    int retval = rig_set_mode(my_rig, RIG_VFO_CURR, mode, width);
+
+    if (retval != RIG_OK) {
+	mvprintw(24, 0,
+		 "Problem with rig link: set mode!\n");
+	refreshp();
+	sleep(1);
+    }
+
+#endif
+}
+
