@@ -49,16 +49,15 @@
 
 void mfj1278_control(int x);
 
-int keyer(void)
-{
+int keyer(void) {
 
     extern int cqmode;
     extern char mode[20];
-    extern char message[][80];
     extern int trxmode;
     extern int cwkeyer;
     extern int digikeyer;
     extern int weight;
+    extern int keyer_backspace;
 
     WINDOW *win = NULL;
     PANEL *panel = NULL;
@@ -66,7 +65,7 @@ int keyer(void)
     int x = 0, j = 0;
     int cury, curx;
     char nkbuffer[2];
-    char keyerstring[KEYER_LINE_WIDTH+1] = "";
+    char keyerstring[KEYER_LINE_WIDTH + 1] = "";
     int keyerstringpos = 0;
     char weightbuf[15];
     const char txcontrolstring[2] = { 20, '\0' };	// ^t
@@ -75,7 +74,7 @@ int keyer(void)
     const char ctl_c_controlstring[2] = { 92, '\0' };	// '\'
 
     if ((trxmode == CWMODE && cwkeyer == NO_KEYER) ||
-	(trxmode == DIGIMODE && digikeyer == NO_KEYER)) /* no keyer present */
+	    (trxmode == DIGIMODE && digikeyer == NO_KEYER)) /* no keyer present */
 	return 1;
 
     strcpy(mode, "Keyboard");
@@ -83,7 +82,7 @@ int keyer(void)
     attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 
     if (panel == NULL) {
-	win = newwin(KEYER_WIN_HEIGHT, KEYER_WIN_WIDTH, KEYER_Y, KEYER_Y );
+	win = newwin(KEYER_WIN_HEIGHT, KEYER_WIN_WIDTH, KEYER_Y, KEYER_Y);
 	if (win == NULL)
 	    return 1;
 	panel = new_panel(win);
@@ -104,9 +103,9 @@ int keyer(void)
 
     while (1) {
 	wattron(win, COLOR_PAIR(C_LOG) | A_STANDOUT);
-	wmove (win, 1, 1);
+	wmove(win, 1, 1);
 	for (j = 0; j < KEYER_LINE_WIDTH; j++) {
-	    waddch (win, ' ');
+	    waddch(win, ' ');
 	}
 	mvwprintw(win, 1, 1, "%s", keyerstring);
 	refreshp();
@@ -134,6 +133,23 @@ int keyer(void)
 	    break;
 	}
 
+
+	if (x == KEY_BACKSPACE
+		|| x == KEY_DC /* delete-character key */
+		|| x == KEY_LEFT) {
+
+	    x = 0;  // default: no operation
+
+	    if (keyer_backspace && keyerstringpos > 0) {
+		//
+		// remove last char
+		//
+		--keyerstringpos;
+		keyerstring[keyerstringpos] = '\0';
+		x = KEY_BACKSPACE;
+	    }
+	}
+
 	// Promote lower case to upper case.
 	if (x > 96 && x < 123)
 	    x = x - 32;
@@ -151,7 +167,7 @@ int keyer(void)
 		/* if display field is full move text one left */
 		if (keyerstringpos == KEYER_LINE_WIDTH - 1) {
 		    for (j = 0; j < KEYER_LINE_WIDTH - 1; j++) {
-		    	keyerstring[j] = keyerstring[j + 1];
+			keyerstring[j] = keyerstring[j + 1];
 		    }
 		    keyerstringpos--;
 		}
@@ -162,10 +178,10 @@ int keyer(void)
 	} else {
 
 	    switch (x) {
-	    case '\n':
-	    case 13:
-	    case KEY_ENTER:
-		{
+		case '|':
+		case '\n':		// Note that '\n', KEY_ENTER, and usually 13
+		case 13:		// Will never happen (converted to space above)
+		case KEY_ENTER: {
 		    if (cwkeyer == MFJ1278_KEYER ||
 			    digikeyer == MFJ1278_KEYER) {
 			sendmessage(crcontrolstring);
@@ -173,24 +189,21 @@ int keyer(void)
 		    break;
 		}
 
-	    case 123:		/* { */
-		{
+		case 123: {	/* { */
 		    if (cwkeyer == MFJ1278_KEYER ||
 			    digikeyer == MFJ1278_KEYER) {
 			sendmessage(txcontrolstring);
 		    }
 		    break;
 		}
-	    case 125:		/* } */
-		{
+		case 125: {	/* } */
 		    if (cwkeyer == MFJ1278_KEYER ||
 			    digikeyer == MFJ1278_KEYER) {
 			sendmessage(rxcontrolstring);
 		    }
 		    break;
 		}
-	    case 92:		/* \ */
-		{
+		case 92: {	/* \ */
 		    if (cwkeyer == MFJ1278_KEYER ||
 			    digikeyer == MFJ1278_KEYER) {
 			sendmessage(ctl_c_controlstring);
@@ -198,8 +211,7 @@ int keyer(void)
 		    break;
 		}
 
-	    case 247:		// Alt-w, set weight
-		{
+		case 247: {	// Alt-w, set weight
 		    mvprintw(1, 0, "Weight=   ");
 		    mvprintw(1, 7, "");
 		    refreshp();
@@ -212,90 +224,77 @@ int keyer(void)
 		    break;
 		}
 
-	    // <Page-Up>, increase CW speed.
-	    case KEY_PPAGE:
-		{
+		// <Page-Up>, increase CW speed.
+		case KEY_PPAGE: {
 		    speedup();
 		    clear_display();
 		    break;
 		}
 
-	    // <Page-Down>, decrease CW speed.
-	    case KEY_NPAGE:
-		{
+		// <Page-Down>, decrease CW speed.
+		case KEY_NPAGE: {
 		    speeddown();
 		    clear_display();
 		    break;
 		}
 
-	    case KEY_F(1):
-		{
+		case KEY_F(1): {
 		    getyx(stdscr, cury, curx);
 		    mvprintw(5, 0, "");
-		    sendmessage(message[0]);	/* F1 */
+		    send_keyer_message(0);	/* F1 */
 		    mvprintw(cury, curx, "");
 		    break;
 		}
-	    case KEY_F(2):
-		{
-		    sendmessage(message[1]);	/* F2 */
+		case KEY_F(2): {
+		    send_keyer_message(1);	/* F2 */
 		    break;
 		}
-	    case KEY_F(3):
-		{
-		    sendmessage(message[2]);	/* F3 */
+		case KEY_F(3): {
+		    send_keyer_message(2);	/* F3 */
 		    break;
 		}
-	    case KEY_F(4):
-		{
-		    sendmessage(message[3]);	/* F4 */
+		case KEY_F(4): {
+		    send_keyer_message(3);	/* F4 */
 		    break;
 		}
-	    case KEY_F(5):
-		{
-		    sendmessage(message[4]);	/* F5 */
+		case KEY_F(5): {
+		    send_keyer_message(4);	/* F5 */
 		    break;
 		}
-	    case KEY_F(6):
-		{
-		    sendmessage(message[5]);	/* F6 */
+		case KEY_F(6): {
+		    send_keyer_message(5);	/* F6 */
 		    break;
 		}
-	    case KEY_F(7):
-		{
-		    sendmessage(message[6]);	/* F7 */
+		case KEY_F(7): {
+		    send_keyer_message(6);	/* F7 */
 		    break;
 		}
-	    case KEY_F(8):
-		{
-		    sendmessage(message[7]);	/* F8 */
+		case KEY_F(8): {
+		    send_keyer_message(7);	/* F8 */
 		    break;
 		}
-	    case KEY_F(9):
-		{
-		    sendmessage(message[8]);	/* F9 */
+		case KEY_F(9): {
+		    send_keyer_message(8);	/* F9 */
 		    break;
 		}
-	    case KEY_F(10):
-		{
-		    sendmessage(message[9]);	/* F10 */
+		case KEY_F(10): {
+		    send_keyer_message(9);	/* F10 */
 		    break;
 		}
 
-	    case KEY_F(11):
-		{
-		    sendmessage(message[10]);	/* F11 */
+		case KEY_F(11): {
+		    send_keyer_message(10);	/* F11 */
 		    break;
 		}
-	    case KEY_F(12):
-		{
+		case KEY_F(12): {
 
-		    sendmessage(message[11]);	/* F12 */
+		    send_keyer_message(11);	/* F12 */
+		    break;
+		}
+		case KEY_BACKSPACE: {
+		    sendmessage("\b");          /* ASCII BS */
 		    break;
 		}
-
-	    default:
-		x = x;
 	    }
 
 	}
@@ -303,9 +302,9 @@ int keyer(void)
     hide_panel(panel);
 
     if (cqmode == CQ)
-        strcpy(mode, "Log     ");
+	strcpy(mode, "Log     ");
     else
-        strcpy(mode, "S&P     ");
+	strcpy(mode, "S&P     ");
 
     clear_display();
 
@@ -314,8 +313,7 @@ int keyer(void)
 
 /* ----------------  convert input for 1278 ctrl -----------------------*/
 
-void mfj1278_control(int x)
-{
+void mfj1278_control(int x) {
     extern int trxmode;
 
     char buffer[2];
