@@ -40,14 +40,7 @@
 #include "store_qso.h"
 #include "tlf_curses.h"
 #include "ui_utils.h"
-
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
-
-#ifdef HAVE_LIBHAMLIB
-# include <hamlib/rig.h>
-#endif
+#include "cleanup.h"
 
 
 pthread_mutex_t disk_mutex = PTHREAD_MUTEX_INITIALIZER;
@@ -58,10 +51,7 @@ pthread_mutex_t disk_mutex = PTHREAD_MUTEX_INITIALIZER;
  *
  * \param from_lan true - Log lanmessage, false - normal message
  */
-int log_to_disk(int from_lan)
-{
-    extern char hiscall[];
-    extern char comment[];
+int log_to_disk(int from_lan) {
     extern char my_rst[];
     extern char his_rst[];
     extern char last_rst[4];
@@ -70,11 +60,6 @@ int log_to_disk(int from_lan)
     extern int rit;
     extern int trx_control;
     extern int cqmode;
-#ifdef HAVE_LIBHAMLIB
-    extern freq_t outfreq;
-#else
-    extern int outfreq;
-#endif
     extern int block_part;
     extern char lan_message[];
     extern char thisnode;
@@ -99,13 +84,9 @@ int log_to_disk(int from_lan)
 	    addspot();		/* add call to bandmap if in S&P and
 				   no need to ask for frequency */
 
-	hiscall[0] = '\0';	/* reset the call  string */
-	comment[0] = '\0';	/* reset the comment  string */
-
 	strncpy(last_rst, his_rst, sizeof(last_rst)); /* remember last report */
-	his_rst[1] = '9';	/* restore RST to 599 */
-	my_rst[1] = '9';
 
+	cleanup_qso();		/* reset qso related parameters */
     } else {			// qso from lan
 
 	strncpy(lan_logline, lan_message + 2, 87);
@@ -165,8 +146,9 @@ int log_to_disk(int from_lan)
 
     sync();
 
-    if ((rit == 1) && (trx_control == 1))
-	outfreq = RESETRIT;
+    if (rit) {
+	set_outfreq(RESETRIT);
+    }
 
     block_part = 0;		/* unblock use partials */
 
