@@ -1,7 +1,7 @@
 /*
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0r@eudxf.org>
- *                    2010-2014 Thomas Beierlein <tb@forth-ev.de>
+ *                    2010-2017 Thomas Beierlein <tb@forth-ev.de>
  *                    2013-2016 Ervin Hegedus - HA2OS <airween@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -58,6 +58,7 @@
 #include "startmsg.h"
 #include "tlf_panel.h"
 #include "ui_utils.h"
+#include "readcabrillo.h"
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -80,13 +81,13 @@ int use_rxvt = 0;
 int use_xterm = 0;
 
 int tlfcolors[8][2] = { {COLOR_BLACK, COLOR_WHITE},
-{COLOR_GREEN, COLOR_YELLOW},
-{COLOR_WHITE, COLOR_RED},
-{COLOR_CYAN, COLOR_WHITE},
-{COLOR_WHITE, COLOR_BLACK},
-{COLOR_WHITE, COLOR_MAGENTA},
-{COLOR_BLUE, COLOR_YELLOW},
-{COLOR_WHITE, COLOR_BLACK}
+    {COLOR_GREEN, COLOR_YELLOW},
+    {COLOR_WHITE, COLOR_RED},
+    {COLOR_CYAN, COLOR_WHITE},
+    {COLOR_WHITE, COLOR_BLACK},
+    {COLOR_WHITE, COLOR_MAGENTA},
+    {COLOR_BLUE, COLOR_YELLOW},
+    {COLOR_WHITE, COLOR_BLACK}
 };
 int debugflag = 0;
 int editor = EDITOR_JOE;
@@ -112,6 +113,7 @@ int minitest = 0;	/**< if set, length of minitest period in seconds */
 int unique_call_multi = 0;          /* do we count calls as multiplier */
 
 int universal = 0;
+
 int addcallarea;
 int pfxmult = 0;
 int pfxmultab = 0;
@@ -126,7 +128,7 @@ int cwpoints;
 int lowband_point_mult = 0;
 int sc_sidetone;
 char sc_volume[4] = "";
-  /* LZ3NY mods */
+/* LZ3NY mods */
 int my_country_points = -1;
 int my_cont_points = -1;
 int dx_cont_points = -1;
@@ -185,7 +187,9 @@ char multsfile[80] = "";	/* name of file with a list of allowed
 char exchange_list[40] = "";
 int timeoffset = 0;
 int trxmode = CWMODE;
-int rigmode = 0;		/* RIG_MODE_NONE in hamlib/rig.h, but if hamlib not compiled, then no dependecy */
+int rigmode = 0;		/* RIG_MODE_NONE in hamlib/rig.h,
+				   but if hamlib not compiled,
+				   then no dependency */
 int mixedmode = 0;
 char his_rst[4] = "599";
 char my_rst[4] = "599";
@@ -215,17 +219,15 @@ char synclogfile[120];
 char markerfile[120] = "";
 int xplanet = 0;
 unsigned char rigptt = 0;
-	/**< Bitmask for Hamlib CAT PTT
-	 * bit 0 set: CAT PTT wanted--RIGPTT in logcfg.dat (set in parse_logcfg)
-	 * bit 1 set: CAT PTT available--from rig caps (set in sendqrg)
-	 * bit 2 set: PTT active (set/unset in gettxinfo)
-	 * bit 3 set: PTT On (set/unset in callinput)
-	 * bit 4 set: PTT Off (set/unset in callinput)
-	 */
+/**< Bitmask for Hamlib CAT PTT
+ * bit 0 set: CAT PTT wanted--RIGPTT in logcfg.dat (set in parse_logcfg)
+ * bit 1 set: CAT PTT available--from rig caps (set in sendqrg)
+ * bit 2 set: PTT active (set/unset in gettxinfo)
+ * bit 3 set: PTT On (set/unset in callinput)
+ * bit 4 set: PTT Off (set/unset in callinput)
+ */
 
-char sp_return[80] = " \n";
-char cq_return[80] = " \n";
-char message[25][80] = /**< Array of CW/DigiMode messages
+char message[25][80] = /**< Array of CW messages
  			*
  			* message[0]..[11] activated by F1..F12 key
  			* message[12] - TU message S&P mode
@@ -246,15 +248,19 @@ char message[25][80] = /**< Array of CW/DigiMode messages
 			* additional use if in CTCOMP mode
 			* message[1]  (F2)  - insert pressed
  			*/
-    { "TEST %\n", "@ DE %\n", "@ [\n", "TU 73\n", " @\n", "%\n",
-	"@ SRI QSO B4 GL\n", "AGN\n",
-	" ?\n", " QRZ?\n", " PSE K\n", "TEST % %\n", "@ [\n", "TU %\n",
-	"", "", "", "", "", "", "", "", "", "", "" };
+{
+    "TEST %\n", "@ DE %\n", "@ [\n", "TU 73\n", " @\n", "%\n",
+    "@ SRI QSO B4 GL\n", "AGN\n",
+    " ?\n", " QRZ?\n", " PSE K\n", "TEST % %\n", "@ [\n", "TU %\n",
+    "", "", "", "", "", "", "", "", "", "", ""
+};
+
+char *digi_message[sizeof(message) / sizeof(message[0])];
 
 char ph_message[14][80] = /**< Array of file names for voice keyer messages
 			   * See description of message[]
 			   */
-	{ "", "", "", "", "", "", "", "", "", "", "", "", "", "" };
+    { "", "", "", "", "", "", "", "", "", "", "", "", "", "" };
 
 char qtc_recv_msgs[12][80] = {"QTC?\n", "QRV\n", "R\n", "", "TIME?\n", "CALL?\n", "NR?\n", "AGN\n", "", "QSL ALL\n", "", ""}; // QTC receive windowS Fx messages
 char qtc_send_msgs[12][80] = {"QRV?\n", "QTC sr/nr\n", "", "", "TIME\n", "CALL\n", "NR\n", "", "", "", "", ""}; // QTC send window Fx messages
@@ -278,8 +284,8 @@ int early_started = 0;			/**< 1 if sending call started early,
 					   strlen(hiscall)>cwstart or 'space' */
 char lastcall[20];
 char qsonrstr[5] = "0001";
-char band[9][4] =
-    { "160", " 80", " 40", " 30", " 20", " 17", " 15", " 12", " 10" };
+char band[NBANDS][4] =
+    { "160", " 80", " 40", " 30", " 20", " 17", " 15", " 12", " 10", "???" };
 char comment[80];
 char mode[20] = "Log     ";
 char cqzone[3] = "";
@@ -288,7 +294,6 @@ char ituzone[3] = "";
 char continent[3] = "";
 char mycontinent[3] = "";
 char pxstr[11] = "";
-int bandindex = 0;
 int totalmults = 0;
 int totalcountries = 0;
 int totalzones = 0;
@@ -296,18 +301,20 @@ int secs = 0;
 int countrynr;
 int mycountrynr = 215;
 int total = 0; 		/**< total number of qso points */
-int band_score[9];
+int band_score[NBANDS];
 int dupe = 0;
 int callfound = 0;
 int partials = 0;	/**< show partial calls */
 int use_part = 0;	/**< if 1 use automatically found partial call */
 int block_part = 0; 	/**< if 1 block the call autocompletion
 			  for these QSO */
-char para_word[80] = "LODNCFS:3C\n";	/* longcw, cluster, search,  DE, contest, filter,  speed,  delay */
+char para_word[80] = "LODNCFS:3C\n";	/* longcw, cluster, search, DE,
+					   contest, filter,  speed,  delay */
 char lastmsg[1000] = "";
-int scale_values[20] =
-    { 40, 38, 36, 34, 32, 30, 28, 26, 24, 22, 20, 18, 16, 14, 12, 10, 8, 6,
-4, 2 };
+int scale_values[20] = {
+    40, 38, 36, 34, 32, 30, 28, 26, 24, 22, 20, 18, 16, 14, 12, 10, 8, 6,
+    4, 2
+};
 char sc_device[40] = "/dev/dsp";
 
 /*-------------------------------------keyer------------------------------*/
@@ -315,9 +322,13 @@ int cwkeyer = NO_KEYER;
 int digikeyer = NO_KEYER;
 
 char keyer_device[10] = "";	// ttyS0, ttyS1, lp0-2 for net_keyer
+int keyer_backspace = 0;        // disabled
 
 char controllerport[80] = "/dev/ttyS0"; // for GMFSK or MFJ-1278
 char rttyoutput[120];		// where to GMFSK digimode output
+#ifdef HAVE_LIBHAMLIB
+rmode_t digi_mode = RIG_MODE_NONE;
+#endif
 
 int txdelay = 0;
 int weight = 0;
@@ -350,18 +361,15 @@ int bmautograb = 0;
 #ifdef HAVE_LIBHAMLIB
 rig_model_t myrig_model = 351;
 RIG *my_rig;			/* handle to rig (instance) */
-freq_t outfreq;			/* output  to rig */
 rmode_t rmode;			/* radio mode of operation */
 pbwidth_t width;
 vfo_t vfo;			/* vfo selection */
 port_t myport;
-#else
-int outfreq;			/* output  to rig */
 #endif
 int ssb_bandwidth = 3000;
 int cw_bandwidth = 0;
 int serial_rate = 2400;
-char rigportname[40];
+char *rigportname;
 int rignumber = 0;
 int rig_comm_error = 0;
 int rig_comm_success = 0;
@@ -378,7 +386,7 @@ char tonecpy[5];
 char simulator_tone[5];
 
 /*-------------------------------the log lines-----------------------------*/
-char qsos[MAX_QSOS][LOGLINELEN+1];
+char qsos[MAX_QSOS][LOGLINELEN + 1];
 int nr_qsos = 0;
 
 /*------------------------------dupe array---------------------------------*/
@@ -389,9 +397,9 @@ struct worked_t worked[MAX_CALLS]; /**< worked stations */
 int countries[MAX_DATALINES];	/* per country bit fieldwith worked bands set */
 int zones[MAX_ZONES];		/* same for cq zones or itu zones;
 				   using 1 - 40 or 1 - 90 */
-char mults[MAX_MULTS][12];
-int mult_bands[MAX_MULTS];
-int multarray_nr = 0;
+
+struct mults_t multis[MAX_MULTS]; /**< worked multis */
+int nr_multis = 0;		/**< number of multis in multis[] */
 
 GPtrArray *mults_possible;
 
@@ -400,7 +408,7 @@ int multlist = 0;
 int callareas[20];
 int multscore[NBANDS];
 
-struct ie_list *main_ie_list;	/* head of initial exchange list */
+struct ie_list *main_ie_list = NULL;	/* head of initial exchange list */
 
 int zonescore[NBANDS];
 int countryscore[NBANDS];
@@ -415,7 +423,7 @@ int qsonum = 1;			/* nr of next QSO */
 int ymax, xmax;			/* screen size */
 
 pid_t pid;
-struct tm *time_ptr;
+struct tm *time_ptr, time_ptr_cabrillo;
 
 float freq;
 float mem;
@@ -423,16 +431,17 @@ int logfrequency = 0;
 int rit;
 int trx_control = 0;
 int showfreq = 0;
-float bandfrequency[9] =
-    { 1830.0, 3525.0, 7010.0, 10105.0, 14025.0, 18070.0, 21025.0, 24900.0,
-28025.0 };
+float bandfrequency[NBANDS] = {
+    1830.0, 3525.0, 7010.0, 10105.0, 14025.0, 18070.0, 21025.0, 24900.0,
+    28025.0, 0.
+};
 
 char headerline[81] =
     "   1=CQ  2=DE  3=RST 4=73  5=HIS  6=MY  7=B4   8=AGN  9=?  \n";
 char backgrnd_str[81] =
     "                                                                                ";
 
-char logline_edit[5][LOGLINELEN+1];
+char logline_edit[5][LOGLINELEN + 1];
 
 char terminal1[88] = "";
 char terminal2[88] = "";
@@ -451,7 +460,6 @@ int m = 1;
 char hiscountry[40];
 
 int this_second;
-int stop_backgrnd_process = 1;	/* dont start until we know what we are doing */
 
 int wazmult = 0;		/* to add the ability of WAZ zones to be multiplier */
 int itumult = 0;		/* to add the ability of ITU zones to be multiplier */
@@ -459,62 +467,66 @@ char itustr[3];
 
 int nopacket = 0;		/* set if tlf is called with '-n' */
 int no_trx_control = 0;		/* set if tlf is called with '-r' */
+int convert_cabrillo = 0;       /* set if the arg input is a cabrillo */
+int do_cabrillo = 0;		/* actually converting cabrillo file to Tlf log */
 
-int bandweight_points[NBANDS] = {1, 1, 1, 1, 1, 1, 1, 1, 1};
-int bandweight_multis[NBANDS] = {1, 1, 1, 1, 1, 1, 1, 1, 1};
+int bandweight_points[NBANDS] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 0};
+int bandweight_multis[NBANDS] = {1, 1, 1, 1, 1, 1, 1, 1, 1, 0};
 
 pthread_t background_thread;
 static struct termios oldt, newt;
 
 /** parse program options
  */
-void parse_options(int argc, char *argv[])
-{
+void parse_options(int argc, char *argv[]) {
     while ((argc > 1) && (argv[1][0] == '-')) {
 	switch (argv[1][1]) {
 	    /* verbose option */
-	case 'f':
-	    if (strlen(argv[1] + 2) > 0) {
-		if ((*(argv[1] + 2) == '~') && (*(argv[1] + 3) == '/')) {
-		    /* tilde expansion */
-		    config_file = g_strconcat( g_get_home_dir(),
-			    argv[1] + 3, NULL);
+	    case 'f':
+		if (strlen(argv[1] + 2) > 0) {
+		    if ((*(argv[1] + 2) == '~') && (*(argv[1] + 3) == '/')) {
+			/* tilde expansion */
+			config_file = g_strconcat(g_get_home_dir(),
+						  argv[1] + 3, NULL);
+		    } else {
+			config_file = g_strdup(argv[1] + 2);
+		    }
 		}
-	    	else {
-		    config_file = g_strdup(argv[1] + 2);
-		}
-	    }
-	    break;
-	case 's':
-	    if (strlen(argv[1] + 2) > 0)
-		strcpy(synclogfile, argv[1] + 2);
-	    break;
-	case 'd':		// debug rigctl
-	    debugflag = 1;
-	    break;
-	case 'v':		// verbose startup
-	    verbose = 1;
-	    break;
-	case 'V':		// output version
-	    printf("Version: tlf-%s\n", VERSION);
-	    exit(0);
-	    break;
-	case 'n':		// disable packet
-	    nopacket = 1;
-	    break;
-	case 'r':
-	    no_trx_control = 1; // disable radio control
-	    break;
-	default:
-	    printf("Use: tlf [-v] Verbose\n");
-	    printf("         [-V] Version\n");
-	    printf("         [-f] Configuration file\n");
-	    printf("         [-d] Debug mode\n");
-	    printf("         [-h] This message\n");
-	    printf("         [-n] Start without cluster hookup\n");
-	    printf("         [-r] Start without radio control\n");
-	    exit(0);
-	    break;
+		break;
+	    case 's':
+		if (strlen(argv[1] + 2) > 0)
+		    strcpy(synclogfile, argv[1] + 2);
+		break;
+	    case 'd':		// debug rigctl
+		debugflag = 1;
+		break;
+	    case 'v':		// verbose startup
+		verbose = 1;
+		break;
+	    case 'V':		// output version
+		printf("Version: tlf-%s\n", VERSION);
+		exit(0);
+		break;
+	    case 'n':		// disable packet
+		nopacket = 1;
+		break;
+	    case 'r':
+		no_trx_control = 1; // disable radio control
+		break;
+	    case 'i':
+		convert_cabrillo = 1;
+		break;
+	    default:
+		printf("Use: tlf [-v] Verbose\n");
+		printf("         [-V] Version\n");
+		printf("         [-f] Configuration file\n");
+		printf("         [-d] Debug mode\n");
+		printf("         [-h] This message\n");
+		printf("         [-n] Start without cluster hookup\n");
+		printf("         [-r] Start without radio control\n");
+		printf("         [-i] Import cabrillo file to Tlf format\n");
+		exit(0);
+		break;
 	}
 	--argc;
 	++argv;
@@ -523,24 +535,23 @@ void parse_options(int argc, char *argv[])
 
 
 /** initialize user interface */
-void ui_init()
-{
+void ui_init() {
+
     /* modify stdin terminals attributes to allow Ctrl-Q/S key recognition */
-    tcgetattr( STDIN_FILENO, &oldt);
+    tcgetattr(STDIN_FILENO, &oldt);
     newt = oldt;
     newt.c_iflag &= ~(IXON);
-    tcsetattr( STDIN_FILENO, TCSANOW, &newt);
+    tcsetattr(STDIN_FILENO, TCSANOW, &newt);
 
-/* getting users terminal string and (if RXVT) setting rxvt colours on it */
-/* LZ3NY hack :) */
+    /* getting users terminal string and (if RXVT) setting rxvt colours on it */
+    /* LZ3NY hack :) */
     char *term = getenv("TERM");
     if (strcasecmp(term, "rxvt") == 0) {
 	use_rxvt = 1;
     } else if (strcasecmp(term, "xterm") == 0) {
 	use_xterm = 1;
 	use_rxvt = 1;
-    } else
-	putenv("TERM=rxvt");	/*or going to native console linux driver */
+    }
 
     /* Check the environment variable ESCDELAY.
      *
@@ -560,7 +571,7 @@ void ui_init()
     if ((mainscreen = newterm(NULL, stdout, stdin)) == NULL) {
 	perror("initscr");
 	printf
-	    ("\nSorry, wrong terminal type !!!!! \nTry a  linux text terminal or set TERM=linux !!!\n");
+	("\nSorry, wrong terminal type !!!!! \nTry a  linux text terminal or set TERM=linux !!!\n");
 	sleep(2);
 
 	exit(EXIT_FAILURE);
@@ -573,11 +584,11 @@ void ui_init()
     if ((ymax < 25) || (xmax < 80)) {
 	char c;
 
-	showmsg( "!! TLF needs at least 25 lines and 80 columns !!");
-	showmsg( "   Continue anyway? Y/(N)" );
-	c = toupper( key_get() );
+	showmsg("!! TLF needs at least 25 lines and 80 columns !!");
+	showmsg("   Continue anyway? Y/(N)");
+	c = toupper(key_get());
 	if (c != 'Y') {
-	    showmsg( "73 es cuagn" );
+	    showmsg("73 es cuagn");
 	    sleep(1);
 	    endwin();
 	    exit(EXIT_FAILURE);
@@ -599,15 +610,15 @@ void ui_init()
     noecho();
     cbreak();
 
-    keypad(stdscr,TRUE);
+    keypad(stdscr, TRUE);
 
     lookup_keys();
 }
 
 
 /* setup colors */
-void ui_color_init()
-{
+void ui_color_init() {
+
     if (use_rxvt == 1) {	// use rxvt colours
 	init_pair(COLOR_BLACK, COLOR_BLACK, COLOR_RED);
 	if (use_xterm == 1) {
@@ -642,8 +653,7 @@ void ui_color_init()
 /** load all databases
  *
  * \return EXIT_FAILURE if not successful */
-int databases_load()
-{
+int databases_load() {
     int status;
 
     showmsg("reading country data");
@@ -654,8 +664,8 @@ int databases_load()
     status |= read_rules();	/* read the additional contest rules
 				   in "rules/contestname" */
     if (status != PARSE_OK) {
-	showmsg( "Problems in logcfg.dat or rule file detected! Continue Y/(N)?");
-	if (toupper( key_get() ) != 'Y') {
+	showmsg("Problems in logcfg.dat or rule file detected! Continue Y/(N)?");
+	if (toupper(key_get()) != 'Y') {
 	    showmsg("73...");
 	    return EXIT_FAILURE;
 	}
@@ -663,7 +673,7 @@ int databases_load()
 
     if (*call == '\0') {
 	showmsg
-	    ("WARNING: No callsign defined in logcfg.dat! exiting...\n\n\n");
+	("WARNING: No callsign defined in logcfg.dat! exiting...\n\n\n");
 	return EXIT_FAILURE;
     }
 
@@ -687,8 +697,8 @@ int databases_load()
 	main_ie_list = make_ie_list(exchange_list);
 
 	if (main_ie_list == NULL) {
-	    showmsg( "Problems in initial exchange file detected! Continue Y/(N)?");
-	    if (toupper( key_get() ) != 'Y') {
+	    showmsg("Problems in initial exchange file detected! Continue Y/(N)?");
+	    if (toupper(key_get()) != 'Y') {
 		showmsg("73...");
 		return EXIT_FAILURE;
 	    }
@@ -697,13 +707,13 @@ int databases_load()
 
     /* make sure logfile is there and has the right format */
     if (checklogfile_new(logfile) != 0) {
-	showmsg( "Can not access logfile. Giving up" );
+	showmsg("Can not access logfile. Giving up");
 	return EXIT_FAILURE;
     }
 
     if (qtcdirection > 0) {
 	if (checkqtclogfile() != 0) {
-	    showmsg( "QTC's giving up" );
+	    showmsg("QTC's giving up");
 	    return EXIT_FAILURE;
 	}
 	readqtccalls();
@@ -715,8 +725,8 @@ int databases_load()
     return 0;
 }
 
-void hamlib_init()
-{
+void hamlib_init() {
+
 #ifdef HAVE_LIBHAMLIB		// Code for hamlib interface
     int status;
 
@@ -736,13 +746,13 @@ void hamlib_init()
 	status = init_tlf_rig();
 
 	if (status  != 0) {
-	    showmsg( "Continue without rig control Y/(N)?");
-	    if (toupper( key_get() ) != 'Y') {
+	    showmsg("Continue without rig control Y/(N)?");
+	    if (toupper(key_get()) != 'Y') {
 		endwin();
 		exit(1);
 	    }
 	    trx_control = 0;
-	    showmsg( "Disabling rig control!");
+	    showmsg("Disabling rig control!");
 	    sleep(1);
 	}
     }
@@ -750,7 +760,7 @@ void hamlib_init()
     showmsg("No Hamlib compiled in!");
 
     trx_control = 0;
-    showmsg( "Disabling rig control!");
+    showmsg("Disabling rig control!");
     sleep(1);
 #endif				/* HAVE_LIBHAMLIB */
 }
@@ -769,8 +779,7 @@ void fldigi_init() {
 #endif
 }
 
-void lan_init()
-{
+void lan_init() {
     if (lan_active == 1) {
 	if (lanrecv_init() < 0)	/* set up the network */
 	    showmsg("LAN receive  init failed");
@@ -785,8 +794,7 @@ void lan_init()
 }
 
 
-void packet_init()
-{
+void packet_init() {
     if (nopacket == 1)
 	packetinterface = 0;
 
@@ -804,8 +812,7 @@ void packet_init()
 }
 
 
-void keyer_init()
-{
+void keyer_init() {
     char keyerbuff[3];
 
     if (cwkeyer == NET_KEYER) {
@@ -857,15 +864,13 @@ void keyer_init()
  * Cleanup initialisations made by tlf. Will be called after exit() from
  * logit() or background_process()
  */
-void tlf_cleanup()
-{
+void tlf_cleanup() {
     if (pthread_self() != background_thread) {
 	pthread_cancel(background_thread);
 	pthread_join(background_thread, NULL);
     }
 
-//    commented out for the moment as it will segfault if called twice
-//    cleanup_telnet();
+    cleanup_telnet();
 
     if (trxmode == CWMODE && cwkeyer == NET_KEYER)
 	netkeyer_close();
@@ -887,7 +892,7 @@ void tlf_cleanup()
 #endif
 
     endwin();
-    tcsetattr( STDIN_FILENO, TCSANOW, &oldt);
+    tcsetattr(STDIN_FILENO, TCSANOW, &oldt);
 }
 
 
@@ -895,8 +900,7 @@ void tlf_cleanup()
 /*     Main loop of the program			                           */
 /* ------------------------------------------------------------------------*/
 
-int main(int argc, char *argv[])
-{
+int main(int argc, char *argv[]) {
     int j;
     int ret;
     char tlfversion[80] = "";
@@ -920,12 +924,9 @@ int main(int argc, char *argv[])
     termbuf[0] = '\0';
     hiscall[0] = '\0';
 
-    strcpy(sp_return, message[SP_TU_MSG]);
-    strcpy(cq_return, message[CQ_TU_MSG]);
-
 
     sprintf(tlfversion,
-	    "        Welcome to tlf-%s by PA0R!!" , VERSION);
+	    "        Welcome to tlf-%s by PA0R!!", VERSION);
     showmsg(tlfversion);
     showmsg("");
 
@@ -936,6 +937,22 @@ int main(int argc, char *argv[])
 	exit(EXIT_FAILURE);
     }
 
+    if (convert_cabrillo == 1) {
+	char tstring[100] = "";
+	sprintf(tstring, "Converting cabrillo for contest %s from file %s.cbr",
+		whichcontest, g_strstrip(call));
+	showmsg(tstring);
+	showmsg("");
+	getstationinfo();
+	if (0 != readcabrillo(READCAB_MODE_CLI))
+	    showmsg("Sorry. Conversion failed....");
+	else
+	    showmsg("Done...");
+	sleep(2);
+	endwin();
+	exit(EXIT_SUCCESS);
+    }
+
     /* now setup colors */
     ui_color_init();
 
@@ -948,7 +965,7 @@ int main(int argc, char *argv[])
     keyer_init();
 
     clear();
-    mvprintw(0, 0, "        Welcome to tlf-%s by PA0R!!\n\n" , VERSION);
+    mvprintw(0, 0, "        Welcome to tlf-%s by PA0R!!\n\n", VERSION);
     refreshp();
 
     checkparameters();		/* check .paras file */
@@ -981,7 +998,7 @@ int main(int argc, char *argv[])
     }
 
     /* now start logging  !! Does never return */
-    logit(NULL);
+    logit();
 
     return 0;
 }
