@@ -22,11 +22,11 @@
 #ifndef LOG_RECV_QTC_TO_DISK_H
 #define LOG_RECV_QTC_TO_DISK_H
 
+#include "cabrillo_utils.h"
 
-int log_recv_qtc_to_disk (int qtcnr);
-int log_sent_qtc_to_disk (int qtcnr);
-void store_recv_qtc (char * loglineptr);
-void store_sent_qtc (char * loglineptr);
-
+void store_qtc(char *loglineptr, int direction, char *filename);
+int log_recv_qtc_to_disk(int qtcnr);
+int log_sent_qtc_to_disk(int qtcnr);
+void make_qtc_logline(struct read_qtc_t qtc_line, char *fname);
 
 #endif /* end of include guard: LOG_RECV_QTC_TO_DISK_H */
