@@ -16,10 +16,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-	/* ------------------------------------------------------------
-	 *        QTC utils functions
-	 *
-	 *--------------------------------------------------------------*/
+/* ------------------------------------------------------------
+ *        QTC utils functions
+ *
+ *--------------------------------------------------------------*/
 
 
 #include <string.h>
@@ -30,7 +30,7 @@
 #include "tlf_curses.h"
 
 
-GHashTable* qtc_store = NULL; 	/* stores number of QTC's per callsign */
+GHashTable *qtc_store = NULL; 	/* stores number of QTC's per callsign */
 struct t_qtc_store_obj *qtc_empty_obj = NULL;
 
 void qtc_init() {
@@ -42,7 +42,7 @@ void qtc_init() {
     if (qtc_empty_obj != NULL) {
 	g_free(qtc_empty_obj);
     }
-    qtc_empty_obj = g_malloc(sizeof (struct t_qtc_store_obj));
+    qtc_empty_obj = g_malloc(sizeof(struct t_qtc_store_obj));
     qtc_empty_obj->total = 0;
     qtc_empty_obj->received = 0;
     qtc_empty_obj->sent = 0;
@@ -50,29 +50,29 @@ void qtc_init() {
 }
 
 void qtc_meta_write() {
+
     struct t_qtc_store_obj *qtc_obj;
-    GList * qtc_key_list;
+    GList *qtc_key_list;
     char logline[20];
-    FILE * fp;
+    FILE *fp;
 
     qtc_key_list = g_hash_table_get_keys(qtc_store);
     if ((fp = fopen(QTC_META_LOG, "w")) == NULL) {
 	mvprintw(5, 0, "Error opening QTC meta logfile.\n");
 	refreshp();
 	sleep(2);
-    }
-    else {
-	while(qtc_key_list != NULL) {
-		qtc_obj = g_hash_table_lookup(qtc_store, qtc_key_list->data);
-		if (qtc_obj->capable == 2) {
-		    sprintf(logline, "%s;L\n", (char *)qtc_key_list->data);
-		    fputs(logline, fp);
-		}
-		if (qtc_obj->capable == -1) {
-		    sprintf(logline, "%s;N\n", (char *)qtc_key_list->data);
-		    fputs(logline, fp);
-		}
-		qtc_key_list = qtc_key_list->next;
+    } else {
+	while (qtc_key_list != NULL) {
+	    qtc_obj = g_hash_table_lookup(qtc_store, qtc_key_list->data);
+	    if (qtc_obj->capable == 2) {
+		sprintf(logline, "%s;L\n", (char *)qtc_key_list->data);
+		fputs(logline, fp);
+	    }
+	    if (qtc_obj->capable == -1) {
+		sprintf(logline, "%s;N\n", (char *)qtc_key_list->data);
+		fputs(logline, fp);
+	    }
+	    qtc_key_list = qtc_key_list->next;
 	}
 	fclose(fp);
     }
@@ -84,7 +84,7 @@ void qtc_inc(char callsign[15], int direction) {
 
     qtc_obj = g_hash_table_lookup(qtc_store, callsign);
     if (qtc_obj == NULL) {
-	qtc_obj = g_malloc0(sizeof (struct t_qtc_store_obj));
+	qtc_obj = g_malloc0(sizeof(struct t_qtc_store_obj));
 	qtc_obj->total = 0;
 	qtc_obj->received = 0;
 	qtc_obj->sent = 0;
@@ -94,10 +94,10 @@ void qtc_inc(char callsign[15], int direction) {
     if (direction == RECV || direction == SEND) {
 	qtc_obj->total++;
 	if (direction == RECV) {
-		qtc_obj->received++;
+	    qtc_obj->received++;
 	}
 	if (direction == SEND) {
-		qtc_obj->sent++;
+	    qtc_obj->sent++;
 	}
     }
     if (direction == QTC_CAP) {
@@ -120,7 +120,7 @@ void qtc_dec(char callsign[15], int direction) {
     qtc_obj = g_hash_table_lookup(qtc_store, callsign);
     if (qtc_obj != NULL) {
 	qtc_obj->total--;
-        if (direction == RECV) {
+	if (direction == RECV) {
 	    qtc_obj->received--;
 	}
 	if (direction == SEND) {
@@ -130,7 +130,8 @@ void qtc_dec(char callsign[15], int direction) {
 
 }
 
-struct t_qtc_store_obj * qtc_get(char callsign[15]) {
+struct t_qtc_store_obj *qtc_get(char callsign[15]) {
+
     struct t_qtc_store_obj *qtc_obj;
 
     if (qtc_store == NULL) {
@@ -145,33 +146,31 @@ struct t_qtc_store_obj * qtc_get(char callsign[15]) {
 
 }
 
-void parse_qtcline(char * logline, char callsign[15], int direction) {
+void parse_qtcline(char *logline, char callsign[15], int direction) {
 
     int i = 0;
 
     if (direction == RECV) {
-	strncpy(callsign, logline+30, 15);
+	strncpy(callsign, logline + 30, 15);
     }
     if (direction == SEND) {
-	strncpy(callsign, logline+35, 15);
+	strncpy(callsign, logline + 35, 15);
     }
-    while(callsign[i] != ' ') {
+    while (callsign[i] != ' ') {
 	i++;
     }
     callsign[i] = '\0';
 }
 
-char qtc_get_value(struct t_qtc_store_obj * qtc_obj) {
+char qtc_get_value(struct t_qtc_store_obj *qtc_obj) {
 
     if (qtc_obj->total > 0) {
 	if (qtc_obj->total == 10) {
 	    return 'Q';
+	} else {
+	    return qtc_obj->total + 48;
 	}
-	else {
-	    return qtc_obj->total+48;
-	}
-    }
-    else {
+    } else {
 	if (qtc_obj->capable == 1) {
 	    return 'P';
 	}
@@ -185,22 +184,22 @@ char qtc_get_value(struct t_qtc_store_obj * qtc_obj) {
     return '\0';
 }
 
-int parse_qtc_flagstr(char * lineptr, char * callsign, char * flag) {
-    char * tmp;
+int parse_qtc_flagstr(char *lineptr, char *callsign, char *flag) {
+    char *tmp;
 
     tmp = strtok(lineptr, ";");
     if (tmp != NULL) {
 	strcpy(callsign, tmp);
 	tmp = strtok(NULL, ";");
 	if (tmp != NULL) {
-	  strncpy(flag, tmp, 1);
-	  return 0;
+	    strncpy(flag, tmp, 1);
+	    return 0;
 	}
     }
     return 1;
 }
 
-void parse_qtc_flagline(char * lineptr) {
+void parse_qtc_flagline(char *lineptr) {
     int rc;
     char callsign[15], flag[2], msg[18];
 
