@@ -19,7 +19,10 @@
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
+#ifndef _GNU_SOURCE
 #define _GNU_SOURCE	// For asprintf()
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
