@@ -28,13 +28,13 @@
 #include <unistd.h>
 
 #include "globalvars.h"		// Includes glib.h and tlf.h
+#include "ignore_unused.h"
 #include "qsonr_to_str.h"
 #include "tlf_curses.h"
 
 
-void scroll_log(void)
-{
-    char *rp;
+void scroll_log(void) {
+
     char inputbuffer[800];
     static int ii, kk;
     int mm;
@@ -53,7 +53,7 @@ void scroll_log(void)
 	inputbuffer[0] = '\0';
 
 	if (fseek(fp, -1L * ii * LOGLINELEN, SEEK_END) == 0)
-	    rp = fgets(inputbuffer, 90, fp);
+	    IGNORE(fgets(inputbuffer, 90, fp));
 	else
 	    strcpy(inputbuffer,
 		   "                                                                                ");
@@ -61,7 +61,7 @@ void scroll_log(void)
 	kk = 5 - ii;
 
 	if (strlen(inputbuffer) <= 10)	/* log repair */
-	    rp = fgets(inputbuffer, 90, fp);
+	    IGNORE(fgets(inputbuffer, 90, fp));;
 
 //              if (strlen(inputbuffer) != LOGLINELEN)
 //                      strcat (inputbuffer, backgrnd_str);
@@ -69,30 +69,30 @@ void scroll_log(void)
 	inputbuffer[80] = '\0';
 
 	switch (kk) {
-	case 0:{
+	    case 0: {
 		strncpy(logline0, inputbuffer, 80);
 		logline0[80] = '\0';
 		break;
 	    }
-	case 1:{
+	    case 1: {
 		strncpy(logline1, inputbuffer, 80);
 		logline1[80] = '\0';
 		break;
 	    }
 
-	case 2:{
+	    case 2: {
 		strncpy(logline2, inputbuffer, 80);
 		logline2[80] = '\0';
 		break;
 
 	    }
-	case 3:{
+	    case 3: {
 		strncpy(logline3, inputbuffer, 80);
 		logline3[80] = '\0';
 		break;
 
 	    }
-	case 4:{
+	    case 4: {
 		strncpy(logline4, inputbuffer, 80);
 		logline4[80] = '\0';
 		break;
