@@ -16,11 +16,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-	/* ------------------------------------------------------------
-	 *
-	 *              Make info string for lower status line
-	 *		x - countrynumber
-	 *--------------------------------------------------------------*/
+/* ------------------------------------------------------------
+ *
+ *              Make info string for lower status line
+ *		x - countrynumber
+ *--------------------------------------------------------------*/
 
 /** Show infos for selected country on bottom of screen
  *
@@ -31,19 +31,21 @@
  */
 
 
+#include <math.h>
 #include <stdio.h>
 #include <string.h>
 #include <time.h>
 
 #include "dxcc.h"
 #include "qrb.h"
+#include "showinfo.h"
 #include "tlf.h"
 #include "tlf_curses.h"
 #include "ui_utils.h"
 
 
-int showinfo(int x)
-{
+int showinfo(int x) {
+
     extern char cqzone[];
     extern char ituzone[];
     extern double DEST_Lat;
@@ -64,11 +66,16 @@ int showinfo(int x)
     char timebuff[80];
 
     dxcc_data *dx;
+    prefix_data *pfx;
     double d;
     time_t now;
     struct tm *ptr1;
 
-    dx = dxcc_by_index(x);
+    if (x == SHOWINFO_DUMMY)
+	pfx = prefix_by_index(prefix_count());
+    else
+	pfx = prefix_by_index(x);
+    dx = dxcc_by_index(pfx -> dxcc_index);
 
     strcpy(pxstr, dx->pfx);
     strcpy(countrystr, dx->countryname);	/* country */
@@ -88,16 +95,28 @@ int showinfo(int x)
 	itustr[2] = '\0';
     }
 
-    d = dx->timezone;				/* GMT difference */
+    if (pfx->timezone != INFINITY)
+	d = pfx->timezone;
+    else
+	d = dx->timezone;				/* GMT difference */
 
     now = (time(0) + (long)((timeoffset - d) * 3600) + timecorr);
     ptr1 = gmtime(&now);
     strftime(timebuff, 80, "%H:%M", ptr1);
 
-    DEST_Lat = dx->lat;				/* where is he? */
-    DEST_Long = dx->lon;
+    if (pfx->lat != INFINITY)
+	DEST_Lat = pfx->lat;
+    else
+	DEST_Lat = dx->lat;				/* where is he? */
+    if (pfx->lon != INFINITY)
+	DEST_Lat = pfx->lon;
+    else
+	DEST_Long = dx->lon;
 
-    strncpy(contstr, dx->continent, 2);	/* continent */
+    if (pfx->continent != NULL)
+	strncpy(contstr, pfx->continent, 2);	/* continent */
+    else
+	strncpy(contstr, dx->continent, 2);	/* continent */
     contstr[2] = '\0';
 
     getyx(stdscr, cury, curx);
@@ -106,8 +125,8 @@ int showinfo(int x)
     mvprintw(24, 0, " %s  %s             ", pxstr, countrystr);
 
     mvprintw(24, 26,
-	 " %s %s                                           ",
-	 contstr, zonestr);
+	     " %s %s                                           ",
+	     contstr, zonestr);
 
     if (x != 0 && x != mycountrynr) {
 	qrb_(&range, &bearing);
