@@ -35,10 +35,13 @@
 #include <unistd.h>
 #include <sys/stat.h>
 
+#define SPLITSCREEN_H_PRIVATE
+
 #include "bandmap.h"
 #include "clear_display.h"
 #include "get_time.h"
 #include "globalvars.h"		// Includes glib.h and tlf.h
+#include "ignore_unused.h"
 #include "lancode.h"
 #include "splitscreen.h"
 #include "sockserv.h"
@@ -83,8 +86,7 @@ struct tln_logline *viewing = NULL;
 int view_state = STATE_EDITING;
 char tln_input_buffer[2 * BUFFERSIZE];
 
-void addlog(char *s)
-{
+void addlog(char *s) {
     extern char lastwwv[];
     extern char spot_ptr[MAX_SPOTS][82];
     extern char lastmsg[];
@@ -95,7 +97,7 @@ void addlog(char *s)
     FILE *fp;
     struct tln_logline *temp;
 
-    pthread_mutex_lock (&spot_ptr_mutex);
+    pthread_mutex_lock(&spot_ptr_mutex);
 
     for (len = 0; len < strlen(s); len += 80) {
 
@@ -130,13 +132,13 @@ void addlog(char *s)
 	}
     }
 
-    pthread_mutex_unlock (&spot_ptr_mutex);
+    pthread_mutex_unlock(&spot_ptr_mutex);
 
     // \todo drop it later tb mar11
     bm_add(s);
 
-    if ((strncmp( s, "WWV", 3) == 0) || strncmp ( s, "WCY", 3) == 0)
-	strncpy (lastwwv, s, 82);
+    if ((strncmp(s, "WWV", 3) == 0) || strncmp(s, "WCY", 3) == 0)
+	strncpy(lastwwv, s, 82);
 
     if (tln_loglines >= maxtln_loglines) {
 	temp = loghead;
@@ -167,30 +169,26 @@ void addlog(char *s)
     logtail = temp;
 }
 
-int logattr(void)
-{
+int logattr(void) {
     if (!viewing)
 	return 0;
     else
 	return viewing->attr;
 }
 
-char *firstlog(void)
-{
+char *firstlog(void) {
     viewing = loghead;
     view_state = STATE_VIEWING;
     return viewing->text;
 }
 
-char *lastlog(void)
-{
+char *lastlog(void) {
     viewing = logtail;
     view_state = STATE_VIEWING;
     return viewing->text;
 }
 
-char *nextlog(void)
-{
+char *nextlog(void) {
     if (view_state == STATE_EDITING)
 	viewing = loghead;
     else if (viewing)
@@ -204,8 +202,7 @@ char *nextlog(void)
     }
 }
 
-char *prevlog(void)
-{
+char *prevlog(void) {
     if (view_state == STATE_EDITING)
 	viewing = logtail;
     else if (viewing)
@@ -219,18 +216,16 @@ char *prevlog(void)
     }
 }
 
-void start_editing(void)
-{
+void start_editing(void) {
     werase(entwin);
     currow = curcol = 0;
     viewing = NULL;
     view_state = STATE_EDITING;
 }
 
-void delete_prev_char(void)
-{
+void delete_prev_char(void) {
     int i, j;
-    int c, cc;
+    chtype c, cc;
     if (currow != 0 || curcol != 0) {
 	if (curcol-- == 0) {
 	    curcol = COLS - 1;
@@ -238,7 +233,7 @@ void delete_prev_char(void)
 	}
 	c = ' ';
 	for (i = ENTRYROWS - 1, j = COLS - 1; i > currow || j >= curcol;
-	     j--) {
+		j--) {
 	    if (j < 0) {
 		j = COLS - 1;
 		i--;
@@ -251,8 +246,7 @@ void delete_prev_char(void)
     }
 }
 
-void right_arrow(void)
-{
+void right_arrow(void) {
     if (++curcol >= COLS) {
 	curcol = 0;
 	if (++currow >= ENTRYROWS) {
@@ -263,8 +257,7 @@ void right_arrow(void)
     wmove(entwin, currow, curcol);
 }
 
-void left_arrow(void)
-{
+void left_arrow(void) {
     if (--curcol < 0) {
 	curcol = COLS - 1;
 	if (--currow < 0) {
@@ -274,8 +267,7 @@ void left_arrow(void)
     wmove(entwin, currow, curcol);
 }
 
-void move_eol(void)
-{
+void move_eol(void) {
     currow = ENTRYROWS - 1;
     curcol = COLS - 1;
     while ((A_CHARTEXT & mvwinch(entwin, currow, curcol)) == ' ') {
@@ -292,8 +284,7 @@ void move_eol(void)
     right_arrow();
 }
 
-void gather_input(char *s)
-{
+void gather_input(char *s) {
     int l = 0;
     int i, j;
     for (i = j = 0; i < ENTRYROWS && j < 81; j++) {
@@ -314,8 +305,7 @@ void gather_input(char *s)
 }
 
 int attop = 0;
-int walkup(void)
-{
+int walkup(void) {
     int i;
     if (attop)
 	return 0;
@@ -329,8 +319,7 @@ int walkup(void)
     return 0;
 }
 
-int walkdn(void)
-{
+int walkdn(void) {
     int i;
     if (!attop)
 	return 0;
@@ -344,8 +333,7 @@ int walkdn(void)
     return 0;
 }
 
-int pageup(int lines)
-{
+int pageup(int lines) {
     int i;
     char *s = NULL;
     walkup();
@@ -364,8 +352,7 @@ int pageup(int lines)
     return (s != NULL);
 }
 
-int pagedn(int lines)
-{
+int pagedn(int lines) {
     int i;
     char *s = NULL;
     walkdn();
@@ -385,8 +372,7 @@ int pagedn(int lines)
 
 char entry_text[BUFFERSIZE];
 
-void viewbottom(void)
-{
+void viewbottom(void) {
     int i;
     char *s;
 
@@ -413,8 +399,7 @@ void viewbottom(void)
     attop = FALSE;
 }
 
-void viewtop(void)
-{
+void viewtop(void) {
     int i;
     char *s;
 
@@ -433,8 +418,7 @@ void viewtop(void)
     attop = FALSE;
 }
 
-void resume_editing(void)
-{
+void resume_editing(void) {
     viewbottom();
     wattrset(sclwin, curattr);
     werase(entwin);
@@ -445,8 +429,7 @@ void resume_editing(void)
     wrefresh(entwin);
 }
 
-void viewlog(void)
-{
+void viewlog(void) {
     attop = FALSE;
     if (walkup()) {
 	view_state = STATE_EDITING;
@@ -460,8 +443,7 @@ void viewlog(void)
 }
 
 int litflag = FALSE;
-int edit_line(int c)
-{
+int edit_line(int c) {
     if (view_state != STATE_EDITING) {
 	if (c == '\n')
 	    resume_editing();
@@ -546,8 +528,7 @@ int edit_line(int c)
     return 0;
 }
 
-void sanitize(char *s)
-{
+void sanitize(char *s) {
     char *t = s;
     for (; *s != '\0'; s++) {
 	if (*s == '\007')
@@ -561,8 +542,7 @@ void sanitize(char *s)
     *t = '\0';
 }
 
-void addtext(char *s)
-{
+void addtext(char *s) {
     extern int lan_active;
     extern char call[];
     extern char hiscall[];
@@ -626,7 +606,7 @@ void addtext(char *s)
 
     // Cluster private spotting interface
     if (strncmp(s, call, strlen(call) - 1) == 0
-	&& strlen(s) < 81 && strchr(s, '>') == NULL) {
+	    && strlen(s) < 81 && strchr(s, '>') == NULL) {
 
 	mvprintw(24, 0,
 		 "                                                                                ");
@@ -703,8 +683,8 @@ void addtext(char *s)
 
 	    if (lan_active == 1 && lanspotflg == 0) {
 		if ((strlen(tln_input_buffer) > 0)
-		    && (tln_input_buffer[0] > 32)
-		    && (tln_input_buffer[0] < 126)) {
+			&& (tln_input_buffer[0] > 32)
+			&& (tln_input_buffer[0] < 126)) {
 		    strncpy(lan_out, tln_input_buffer, 78);
 		    lan_out[78] = '\0';
 		    strcat(lan_out, "\n");
@@ -735,8 +715,7 @@ void addtext(char *s)
 WINDOW *packet_win;
 PANEL  *packet_panel;
 
-int init_packet(void)
-{
+int init_packet(void) {
     extern int portnum;
     extern char pr_hostaddress[];
     extern char spot_ptr[MAX_SPOTS][82];
@@ -749,7 +728,6 @@ int init_packet(void)
 
     struct termios termattribs;
 
-    int addrarg;
     int iptr = 0;
     mode_t mode = 0666;
 
@@ -758,11 +736,9 @@ int init_packet(void)
     attr[MINE_ATTR] = modify_attr(A_NORMAL);
     attr[ENTRY_ATTR] = modify_attr(A_NORMAL);
 
-    addrarg = 0;
-
     if (initialized == 0) {
 
-	packet_win = newwin(LINES,COLS,0,0);
+	packet_win = newwin(LINES, COLS, 0, 0);
 	packet_panel = new_panel(packet_win);
 	show_panel(packet_panel);
 	refreshp();
@@ -836,7 +812,7 @@ int init_packet(void)
 	} else {
 	    if (tncport == 1) {
 		if ((fdSertnc =
-		     open("/dev/ttyS0", O_RDWR | O_NONBLOCK)) < 0) {
+			    open("/dev/ttyS0", O_RDWR | O_NONBLOCK)) < 0) {
 		    wprintw(sclwin, "open of /dev/ttyS0 failed!!!\n");
 		    wrefresh(sclwin);
 		    sleep(2);
@@ -845,7 +821,7 @@ int init_packet(void)
 	    } else if (tncport == 2) {
 
 		if ((fdSertnc =
-		     open("/dev/ttyS1", O_RDWR | O_NONBLOCK)) < 0) {
+			    open("/dev/ttyS1", O_RDWR | O_NONBLOCK)) < 0) {
 		    wprintw(sclwin, "open of /dev/ttyS1 failed!!!\n");
 		    wrefresh(sclwin);
 		    sleep(2);
@@ -865,30 +841,30 @@ int init_packet(void)
 
 	switch (tnc_serial_rate) {
 
-	case 1200:{
+	    case 1200: {
 		cfsetispeed(&termattribs, B1200);	/* Set input speed */
 		cfsetospeed(&termattribs, B1200);	/* Set output speed */
 		break;
 	    }
 
-	case 2400:{
+	    case 2400: {
 		cfsetispeed(&termattribs, B2400);	/* Set input speed */
 		cfsetospeed(&termattribs, B2400);	/* Set output speed */
 		break;
 	    }
 
-	case 4800:{
+	    case 4800: {
 		cfsetispeed(&termattribs, B4800);	/* Set input speed */
 		cfsetospeed(&termattribs, B4800);	/* Set output speed */
 		break;
 	    }
 
-	case 9600:{
+	    case 9600: {
 		cfsetispeed(&termattribs, B9600);	/* Set input speed */
 		cfsetospeed(&termattribs, B9600);	/* Set output speed */
 		break;
 	    }
-	default:{
+	    default: {
 
 		cfsetispeed(&termattribs, B9600);	/* Set input speed */
 		cfsetospeed(&termattribs, B9600);	/* Set output speed */
@@ -933,10 +909,10 @@ int init_packet(void)
     wprintw(sclwin, "\n Use \":\" to go to tlf !! \n");
     wrefresh(sclwin);
 
-    pthread_mutex_lock (&spot_ptr_mutex);
+    pthread_mutex_lock(&spot_ptr_mutex);
     for (iptr = 0; iptr < MAX_SPOTS; iptr++)
 	spot_ptr[iptr][0] = '\0';
-    pthread_mutex_unlock (&spot_ptr_mutex);
+    pthread_mutex_unlock(&spot_ptr_mutex);
 
     return (0);
 }
@@ -948,12 +924,15 @@ int init_packet(void)
 =
 ===========================================*/
 
-int cleanup_telnet(void)
-{
+int cleanup_telnet(void) {
 
     extern int packetinterface;
     extern int fdSertnc;
 
+    if (!initialized) {
+	return 0;
+    }
+
     if (packetinterface == TELNET_INTERFACE) {
 	if (prsock > 0)
 	    close_s(prsock);
@@ -993,8 +972,7 @@ int cleanup_telnet(void)
 =
 ===========================================*/
 
-int packet()
-{
+int packet() {
 
     extern int fdSertnc;
     extern int packetinterface;
@@ -1003,9 +981,13 @@ int packet()
     char line[BUFFERSIZE];
 
     int i = 0;
-    int c, count;
+    int c;
     static int sent_login = 0;
 
+    if (!initialized) {
+	return 0;
+    }
+
     in_packetclient = 1;
     sleep(1);
 
@@ -1016,12 +998,10 @@ int packet()
     wclear(entwin);
     wrefresh(entwin);
 
-    count = 0;
-
     if ((tln_loglines == 0) && (packetinterface == TELNET_INTERFACE)) {
 	addtext("Welcome to TLF telnet\n\n");
 	if ((sent_login == 0) && (strlen(clusterlogin) > 0)
-	    && (packetinterface == TELNET_INTERFACE) && (prsock > 0)) {
+		&& (packetinterface == TELNET_INTERFACE) && (prsock > 0)) {
 	    usputs(prsock, clusterlogin);
 	    sent_login = 1;
 	    addtext("logged into cluster...\n\n");
@@ -1127,10 +1107,9 @@ int packet()
 	    }
 
 	    if (packetinterface == TNC_INTERFACE) {
-		int rc;
 		line[strlen(line) - 1] = 13;
 		line[strlen(line)] = '\0';
-		rc = write(fdSertnc, line, strlen(line));
+		IGNORE(write(fdSertnc, line, strlen(line)));;
 	    }
 
 	    curattr = attr[NORMAL_ATTR];
@@ -1158,8 +1137,7 @@ int packet()
 ========================================================
 */
 
-int receive_packet(void)
-{
+int receive_packet(void) {
     extern int packetinterface;
     extern int fdSertnc;
 
@@ -1224,13 +1202,12 @@ int receive_packet(void)
 */
 #define MAX_CMD_LEN 60
 
-int send_cluster(void)
-{
+int send_cluster(void) {
     extern int fdSertnc;
     extern int packetinterface;
     extern int cluster;
 
-    char line[MAX_CMD_LEN+2] = "";
+    char line[MAX_CMD_LEN + 2] = "";
 
     cluster = CLUSTER;
     mvprintw(24, 0,
@@ -1245,13 +1222,11 @@ int send_cluster(void)
 	strcat(line, "\n");
 
 	if (packetinterface == TNC_INTERFACE) {
-	    int rc;
 	    line[strlen(line) - 1] = '\r';
 	    line[strlen(line)] = '\0';	/* not needed */
 
-	    rc = write(fdSertnc, line, strlen(line));
-	}
-	else if ((packetinterface == TELNET_INTERFACE) && (prsock > 0))
+	    IGNORE(write(fdSertnc, line, strlen(line)));;
+	} else if ((packetinterface == TELNET_INTERFACE) && (prsock > 0))
 	    usputs(prsock, line);
     }
 
