@@ -26,6 +26,7 @@
 #include <glib.h>
 
 #include "clear_display.h"
+#include "ignore_unused.h"
 #include "netkeyer.h"
 #include "tlf.h"
 #include "tlf_curses.h"
@@ -39,26 +40,25 @@ pthread_mutex_t keybuffer_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 /** append string to key buffer*/
 void keyer_append(const char *string) {
-    pthread_mutex_lock( &keybuffer_mutex );
+    pthread_mutex_lock(&keybuffer_mutex);
     g_strlcat(wkeyerbuffer, string, sizeof(wkeyerbuffer));
     data_ready = 1;
-    pthread_mutex_unlock( &keybuffer_mutex );
+    pthread_mutex_unlock(&keybuffer_mutex);
 }
 
 /** flush key buffer */
 void keyer_flush() {
-    pthread_mutex_lock( &keybuffer_mutex );
+    pthread_mutex_lock(&keybuffer_mutex);
     wkeyerbuffer[0] = '\0';
     data_ready = 0;
-    pthread_mutex_unlock( &keybuffer_mutex );
+    pthread_mutex_unlock(&keybuffer_mutex);
 }
 
 
 /** write key buffer to keying device
  *
  * should be called periodically from the background task */
-int write_keyer(void)
-{
+int write_keyer(void) {
 
     extern int trxmode;
     extern int cwkeyer;
@@ -67,28 +67,27 @@ int write_keyer(void)
     extern char rttyoutput[];
 
     FILE *bfp = NULL;
-    int rc;
-    char outstring[420] = "";	// this was only 120 char length, but wkeyerbuffer is 400
+    char outstring[420] =
+	"";	// this was only 120 char length, but wkeyerbuffer is 400
     char *tosend = NULL;
 
     if (trxmode != CWMODE && trxmode != DIGIMODE)
 	return (1);
 
-    pthread_mutex_lock( &keybuffer_mutex );
+    pthread_mutex_lock(&keybuffer_mutex);
     if (data_ready == 1) {
 	/* allocate a copy of the data and free the buffer */
 	tosend = g_strdup(wkeyerbuffer);
 	wkeyerbuffer[0] = '\0';
 	data_ready = 0;
     }
-    pthread_mutex_unlock( &keybuffer_mutex );
+    pthread_mutex_unlock(&keybuffer_mutex);
 
     if (tosend != NULL) {
 
 	if (digikeyer == FLDIGI && trxmode == DIGIMODE) {
 	    fldigi_send_text(tosend);
-	}
-	else if (cwkeyer == NET_KEYER) {
+	} else if (cwkeyer == NET_KEYER) {
 	    netkeyer(K_MESSAGE, tosend);
 
 	} else if (cwkeyer == MFJ1278_KEYER || digikeyer == MFJ1278_KEYER) {
@@ -107,15 +106,15 @@ int write_keyer(void)
 		mvprintw(24, 0, "No modem file specified!");
 	    }
 	    // when GMFSK used (possible Fldigi interface), the trailing \n doesn't need
-	    if (tosend[strlen(tosend)-1] == '\n') {
-		tosend[strlen(tosend)-1] = '\0';
+	    if (tosend[strlen(tosend) - 1] == '\n') {
+		tosend[strlen(tosend) - 1] = '\0';
 	    }
 	    sprintf(outstring, "echo -n \"\n%s\" >> %s",
 		    tosend, rttyoutput);
-	    rc = system(outstring);
+	    IGNORE(system(outstring));;
 	}
 
-	g_free (tosend);
+	g_free(tosend);
 	tosend = NULL;
     }
     return (0);
